/*
Class-name: MyMenu.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package gui;

import interfaces.ExportImportObject;
import interfaces.Layer;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JRadioButtonMenuItem;
import simulator.SimulatorPanel;

import modeller.ModellerPanel;
import modeller.ModellerStack;
import modeller.layer.LayerFrame;
import modeller.tools.ImportObjects;
import modeller.tools.ImportUrlClass;

public class MyMenu extends JMenuBar implements ActionListener, MouseListener
{
//	private final int PROJECT_ITEMS = 0;
//	private final int CAD_ITEMS = 1;
	
	private ModellerStack modellerStack;
	private JMenu file, properties, simulator, mode, layer, help, openCad, saveCadAs;
	private MyZoomMenu zoom;
	private JMenuItem openProject, saveProject, saveProjectAs, saveCad;
	JPanel contentPanel;
	private ModellerPanel modellerPanel;
	private SimulatorPanel simulatorPanel;
	
	/**
	 * Constructor<br>
	 * @param contentPanel
	 * @param modellerPanel
	 * @param simulatorPanel
	 */
	public MyMenu(JPanel contentPanel, ModellerPanel modellerPanel, SimulatorPanel simulatorPanel, ModellerStack modellerStack)
	{
		this.contentPanel = contentPanel;
		this.modellerPanel = modellerPanel;
		this.simulatorPanel = simulatorPanel;
		this.modellerStack = modellerStack;
		
		modellerStack.myMenu = this;
		
		new ProjectProperties(modellerStack);	// Initializing the Project-Menu
				
		initMenu();
	}
	
	/**
	 * Initialising the components of the main-manu
	 *
	 */
	private void initMenu()
	{
		JRadioButtonMenuItem rmi;
		JMenuItem mi;
		ButtonGroup buttonGroup = new ButtonGroup();
		ImportObjects importObject;
		
		file	   = new JMenu("File");		// Menu for all file-operations
//		properties =
		simulator  = new JMenu("Simulator");	// Menu for the simulator-GUI
		mode	   = new JMenu("Mode");		// Menu for switching between the modelling- and the simulatorarea 
		layer	   = new JMenu("Layer");
		zoom 	   = new MyZoomMenu("Zoom", modellerStack);
		help	   = new JMenu("Help");
		
		simulator.addMouseListener(this);
		layer.addMouseListener(this);
		zoom.addMouseListener(this);
		
		// Add MenuItems for project
		openProject = new JMenuItem("Open project", new ImageIcon("images/icons/16x16/document-open.png"));
		openProject.setName("openProject"); openProject.setEnabled(false); //openProject.setVisible(false); 
		openProject.addActionListener(this);
		file.add(openProject);
		saveProject = new JMenuItem("Save project", new ImageIcon("images/icons/16x16/document-save.png"));
		saveProject.setName("saveProject"); saveProject.setEnabled(false); // saveProject.setVisible(false); 
		saveProject.addActionListener(this);
		file.add(saveProject);
		saveProjectAs = new JMenuItem("Save project", new ImageIcon("images/icons/16x16/document-save-as.png"));
		saveProjectAs.setName("saveProjectAs"); saveProjectAs.setEnabled(false); // saveProjectAs.setVisible(false); 
		saveProjectAs.addActionListener(this);
		file.add(saveProjectAs);
		
		// Add MenuItems simulator-GUI
		String[] splitOfSimulatorClassesNames = modellerStack.simulatorClassesNames.split(",");
		for(int i=0; i< splitOfSimulatorClassesNames.length; i++) {
			importObject = modellerStack.importUrlClass.getImportObjects().get(splitOfSimulatorClassesNames[i]);
			mi = new JMenuItem(importObject.getToolTipText());
			mi.setName(importObject.getName());
			mi.setEnabled(importObject.isEnabled());
			mi.setVisible(importObject.isVisible());
			mi.addActionListener(this);
			simulator.add(mi);
			try {
				ExportImportObject exportImportObject = modellerStack.importUrlClass.getExportObject(importObject.getName(), importObject.getPath(), ImportUrlClass.IMPORT_SIMULATOR);
				exportImportObject.setObjectData(modellerStack.cadObjects, modellerStack.layers);
				exportImportObject.setName(importObject.getName());
				exportImportObject.setCurrentFilePath(importObject.getPath());
				modellerStack.simulatorObject.put(importObject.getName(), exportImportObject);
		}
		catch (Exception e1) { e1.printStackTrace(); }

		}		
		// Add MenuItems simulator-GUI - END

		// --- Add MenuItems for 2D/3D-modelling objects ---
		//Adding the import-filters
		openCad = new JMenu("Open 2D/3D modell");
		openCad.setIcon(new ImageIcon("images/icons/16x16/document-open.png"));
		openCad.setName("openCad"); openCad.setEnabled(true); // openCad.setVisible(false);
		openCad.addMouseListener(this);
		String[] splitOfImportFormatNames = modellerStack.importFormatNames.split(",");
		for(int i=0; i< splitOfImportFormatNames.length; i++) {
			importObject = modellerStack.importUrlClass.getImportObjects().get(splitOfImportFormatNames[i]);
			mi = new JMenuItem(importObject.getToolTipText());
			mi.setName(importObject.getName());
			mi.setEnabled(importObject.isEnabled());
			mi.setVisible(importObject.isVisible());
			mi.addActionListener(this);
			openCad.add(mi);
		}		
		file.add(openCad);
		//Adding the import-filters - END

		//Adding the export-filters
		saveCad = new JMenuItem("Save 2D/3D modell", new ImageIcon("images/icons/16x16/document-save.png"));
		saveCad.setName("saveCad"); saveCad.setEnabled(false); // saveCad.setVisible(false);
		saveCad.addActionListener(this);
		file.add(saveCad);
		saveCadAs = new JMenu("Save 2D/3D modell as ...");
		saveCadAs.setIcon(new ImageIcon("images/icons/16x16/document-save-as.png"));
		saveCadAs.setName("saveCadAs"); saveCadAs.setEnabled(true); // saveCadAs.setVisible(false);
		String[] splitOfExportFormatNames = modellerStack.exportFormatNames.split(",");
		for(int i=0; i< splitOfExportFormatNames.length; i++) {
			importObject = modellerStack.importUrlClass.getImportObjects().get(splitOfExportFormatNames[i]);
			mi = new JMenuItem(importObject.getToolTipText());
			mi.setName(importObject.getName());
			mi.setEnabled(importObject.isEnabled());
			mi.setVisible(importObject.isVisible());
			mi.addActionListener(this);
			saveCadAs.add(mi);
		}		
		file.add(saveCadAs);
		file.addSeparator();
		//Adding the export-filters - END

		mi = new JMenuItem("Exit", new ImageIcon("images/icons/16x16/system-log-out.png"));	mi.setName("exit"); mi.setEnabled(false);
		mi.addActionListener(this);
		file.add(mi);

		
		// Add MenuItems for the layers
		mi = new JMenuItem("Open layerset");	mi.setName("openLayerset"); mi.setEnabled(false);
		mi.addActionListener(this);
		layer.add(mi);
		mi = new JMenuItem("Save layerset");	mi.setName("saveLayerset"); mi.setEnabled(false);
		mi.addActionListener(this);
		layer.add(mi);
		layer.addSeparator();
		mi = new JMenuItem("Add layer");	mi.setName("addLayer");
		mi.addActionListener(this);
		layer.add(mi);
		mi = new JMenuItem("Delete layer");	mi.setName("deleteLayer"); mi.setEnabled(false);
		mi.addActionListener(this);
		layer.add(mi);
		mi = new JMenuItem("Edit layer");	mi.setName("editLayer");
		mi.addActionListener(this);
		layer.add(mi);
		// Add MenuItems for the layers -END

		mi = new JMenuItem("About OSP");	mi.setName("about");
		mi.addActionListener(this);
		help.add(mi);
		
		// Add RadioButtons
		rmi = new JRadioButtonMenuItem("Simulator");	rmi.setName("simulator");
		rmi.addActionListener(this);
		buttonGroup.add(rmi);
		mode.add(rmi);
		rmi = new JRadioButtonMenuItem("CAD-Tool");		rmi.setName("modeller");
		rmi.setSelected(true);
		rmi.addActionListener(this);
		buttonGroup.add(rmi);
		mode.add(rmi);
		// Add RadioButtons - END
		
		// Adding all Menus
		this.add(file);
		this.add(mode);
		this.add(simulator);
		this.add(layer);
		this.add(zoom);
		this.add(new ProjectMenu(modellerStack)); //new ViewMenu(modellerStack));
		this.add(help);
		// Adding all Menus - END
		
		// Preselecting the CAD-Mode
		contentPanel.setVisible(false);
		contentPanel.add(modellerPanel);
		contentPanel.setVisible(true);
		// Preselecting the CAD-Mode - END
	}

	public void layerEventPerformed(String name)
	{
		if(name.equals("addLayer")) {
			modellerStack.layers.add(new Layer("Layer "+modellerStack.layers.size(), modellerStack.layers.size()));
			if(modellerStack.cadObjects.size()>0)
				modellerStack.objectsProperties.updateObjectList(true);	// modellerStack.cadObjects.get(modellerStack.selectedObject), 
			else
				modellerStack.objectsProperties.updateLayerCB();
			
			modellerStack.layerPanel[0].updateLayer(modellerStack.layers.size()-1);
			modellerStack.layerPanel[1].updateLayer(modellerStack.layers.size()-1);
			modellerStack.objectsPanel.updateObjectTree();
		}
		else if(name.equals("deleteLayer")) {
		}
		else if(name.equals("editLayer")) {
			modellerStack.layerFrame.setVisible(true);
		}
	}
	
//	private void switchMenuItems(int entrys)
//	{
//		switch(entrys) {
//		case PROJECT_ITEMS:
//			openCad.setVisible(false); saveCad.setVisible(false); saveCadAs.setVisible(false);
//			openProject.setVisible(true); saveProject.setVisible(true); saveProjectAs.setVisible(true);
//			break;
//		case CAD_ITEMS:
//			openCad.setVisible(true); saveCad.setVisible(true); saveCadAs.setVisible(true);
//			openProject.setVisible(false); saveProject.setVisible(false); saveProjectAs.setVisible(false);
//			break;
//		}
//	}
	
	public void actionPerformed(ActionEvent e)
	{
		
		if(e.getSource() instanceof JRadioButtonMenuItem) {
			JRadioButtonMenuItem rmi = (JRadioButtonMenuItem)(e.getSource());
			
			System.out.println(rmi.getName());
			
			if(rmi.getName().equals("simulator")) {
				contentPanel.setVisible(false);
				contentPanel.removeAll();
				contentPanel.add(simulatorPanel);
				contentPanel.setVisible(true);
			}else if(rmi.getName().equals("modeller")) {
				contentPanel.setVisible(false);
				contentPanel.removeAll();
				contentPanel.add(modellerPanel);
				contentPanel.setVisible(true);
			}
		} else if((e.getSource()) instanceof JMenuItem) {
			System.out.println(e.getActionCommand()+" - "+e.getSource().getClass().getCanonicalName());

			JMenuItem mi = (JMenuItem)(e.getSource());
			
			if(mi.getName().equals("about"))
				new About();
			else if(mi.getName().indexOf("Layer")>0)
				layerEventPerformed(mi.getName());
			else {
				if(modellerStack.exportFormatNames.indexOf(mi.getName())>-1) {
					try {
						String path = modellerStack.importUrlClass.getImportObjects().get(mi.getName()).getPath();
//						System.out.println("ExportFilter: path="+path+" name="+mi.getName());
						modellerStack.importUrlClass.importClass(mi.getName(), path, ImportUrlClass.EXPORTFILTER);
					}
					catch (Exception e1) { e1.printStackTrace(); }
				}
				else if(modellerStack.importFormatNames.indexOf(mi.getName())>-1) {
					try {
						String path = modellerStack.importUrlClass.getImportObjects().get(mi.getName()).getPath();
//						System.out.println("ImportFilter: path="+path+" name="+mi.getName());
						modellerStack.importUrlClass.importClass(mi.getName(), path, ImportUrlClass.IMPORTFILTER);
					}
					catch (Exception e1) { e1.printStackTrace(); }
				}
				if(modellerStack.simulatorClassesNames.indexOf(mi.getName())>-1) {
//					System.out.println("Simulator-Class");
					modellerStack.simulatorObject.get(mi.getName()).setVisible(true);
				}
			}
		}
	}

	public void mouseClicked(MouseEvent e)
	{
		if(e.getSource()==layer || e.getSource()==zoom || e.getSource()==openCad) { // rb.getName().equals("modeller")) {
//			layer.setVisible(true);			// Setting the layer-panel visible
//			switchMenuItems(CAD_ITEMS);
			contentPanel.setVisible(false);
			contentPanel.removeAll();
			contentPanel.add(modellerPanel);
			contentPanel.setVisible(true);
		} else if(e.getSource()==simulator) { // rb.getName().equals("simulator")) {
//			layer.setVisible(false);				// Setting the layer-panel invisible
//			switchMenuItems(PROJECT_ITEMS);
			
//			contentPanel.setVisible(false);
//			contentPanel.removeAll();
//			contentPanel.add(simulatorPanel);
//			contentPanel.setVisible(true);
		}
	}

	public void mouseEntered(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseExited(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mousePressed(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseReleased(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}
}
