package gui;

import static modeller.tools.StaticMethods.autoSizeCADObjects;

import interfaces.CadObject;
import interfaces.GuiInterface;
import interfaces.Vertex;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.SwingConstants;

import modeller.ModellerStack;

public class ProjectProperties extends JFrame implements GuiInterface, ActionListener, MouseListener
{
	private ModellerStack modellerStack;
	private JTabbedPane tabbedPane;
	private JPanel contentPanel;
	private JPanel projectPropertiesPanel, cadPropertiesPanel, simulatorPropertiesPanel;
	private JTextField boundaryWidth, boundaryHeight, boundaryDepth, rasterWidth, pixelPerMm, background;
	private JButton autoSize;
	private Dimension lSize = new Dimension(95, 20); 
	private Dimension tfSize = new Dimension(145, 20);
	private Dimension fullSize = new Dimension(260, 20);

	public ProjectProperties(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		
		setTitle("Properties");
		setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
		setResizable(false);
		setAlwaysOnTop(true);
		setSize(400, 400);
		
		modellerStack.guiObjects.put("properties", this);
		
		initComponents();
	}
	
	private void initComponents()
	{
		contentPanel = new JPanel(); contentPanel.setLayout(new GridLayout(1, 1));
		tabbedPane = new JTabbedPane();
		
		projectPropertiesPanel = new JPanel();	// projectProperties.setLayout(new BorderLayout());
		cadPropertiesPanel = new JPanel();		// cadProperties.setLayout(new BorderLayout());
		simulatorPropertiesPanel = new JPanel();
		
		cadPropertiesPanel.add(initCadProperties());
		
		tabbedPane.add("Cad-Properties", cadPropertiesPanel);
		tabbedPane.add("Simulator-Properties", simulatorPropertiesPanel);
		tabbedPane.add("Project-Properties", projectPropertiesPanel);
		
		contentPanel.add(tabbedPane);
		
		add(contentPanel);
		
	}
	
	private Box initCadProperties()
	{
		Box vBox = Box.createVerticalBox();
		Box hBox = Box.createHorizontalBox();
		
		JLabel swapLabel;
		
		swapLabel = new JLabel("Width (px)  ", SwingConstants.RIGHT); 	swapLabel.setPreferredSize(lSize);
		boundaryWidth = new JTextField("800");	boundaryWidth.setPreferredSize(tfSize);
		boundaryWidth.addActionListener(this);
		hBox.add(swapLabel);
		hBox.add(boundaryWidth);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));
		
		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("Height (px)  ", SwingConstants.RIGHT); 	swapLabel.setPreferredSize(lSize);
		boundaryHeight = new JTextField("800");	boundaryHeight.setPreferredSize(tfSize);
		boundaryHeight.addActionListener(this);
		hBox.add(swapLabel);
		hBox.add(boundaryHeight);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));
		
		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("Depth (px)  ", SwingConstants.RIGHT); 	swapLabel.setPreferredSize(lSize);
		boundaryDepth = new JTextField("800");	boundaryDepth.setPreferredSize(tfSize);
		boundaryDepth.addActionListener(this);
		hBox.add(swapLabel);
		hBox.add(boundaryDepth);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));
		
		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("Rasterwidth (px)  ", SwingConstants.RIGHT); 	swapLabel.setPreferredSize(lSize);
		rasterWidth = new JTextField("50");			rasterWidth.setPreferredSize(tfSize);
		rasterWidth.addActionListener(this);
		hBox.add(swapLabel);
		hBox.add(rasterWidth);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));

		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("mm per pixel  ", SwingConstants.RIGHT); 	swapLabel.setPreferredSize(lSize);
		pixelPerMm = new JTextField("1");		pixelPerMm.setPreferredSize(tfSize);
		pixelPerMm.addActionListener(this);
		hBox.add(swapLabel);
		hBox.add(pixelPerMm);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));

		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("Background  ", SwingConstants.RIGHT);	swapLabel.setPreferredSize(lSize);
		background = new JTextField("");		background.setPreferredSize(tfSize);
		background.setBackground(Color.LIGHT_GRAY);
		background.setEditable(false);
		background.addMouseListener(this);
		hBox.add(swapLabel);
		hBox.add(background);
//		vBox.add(hBox);
//		vBox.add(Box.createVerticalStrut(4));
		
		hBox = Box.createHorizontalBox();
		swapLabel = new JLabel("  ", SwingConstants.RIGHT);	swapLabel.setPreferredSize(lSize);
		autoSize = new JButton("Autosize CAD-objects"); autoSize.setPreferredSize(tfSize);
//		autoSize.setMinimumSize(fullSize);
		autoSize.addActionListener(this);		
		hBox.add(swapLabel);
		hBox.add(autoSize);
		vBox.add(hBox);
		vBox.add(Box.createVerticalStrut(4));
		
		return vBox;
	}

	public void actionPerformed(ActionEvent e)
	{
		Object obj = e.getSource();
		
//		System.out.println(e.getActionCommand());

		if(obj==boundaryWidth) {
			modellerStack.boundaryWidth = new Double(boundaryWidth.getText());
			modellerStack.repaintDrawPanels();
		}
		else if(obj==boundaryHeight) {
			modellerStack.boundaryHeight = new Double(boundaryHeight.getText());
			modellerStack.repaintDrawPanels();
		}
		else if(obj==boundaryDepth) {
			modellerStack.boundaryDepth = new Double(boundaryDepth.getText());
			modellerStack.repaintDrawPanels();
		}
		else if(obj==rasterWidth) {
			modellerStack.rasterWidth = new Double(rasterWidth.getText());
			modellerStack.repaintDrawPanels();
		}
		else if(obj==pixelPerMm) {
			modellerStack.pixelPerMm = new Double(pixelPerMm.getText());
			modellerStack.repaintDrawPanels();
//			modellerStack.cadObjects.
		}
		else if(obj==autoSize) {
//			System.out.println("AUTOSIZE");
			autoSizeCADObjects(modellerStack);
		}
	}

	public JPanel getPanel()
	{
		return contentPanel;
	}

	public void mouseClicked(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mousePressed(MouseEvent e)
	{
		Object obj = e.getSource();
		
		if(obj==background) {
			Color swapColor = JColorChooser.showDialog(null, "Choose new fillcolor", background.getBackground());
			System.out.println(swapColor);
			if(swapColor!=null) {
				background.setBackground(swapColor);
				modellerStack.drawPanels[0].setPanelBackground(swapColor);
				modellerStack.drawPanels[1].setPanelBackground(swapColor);
				modellerStack.drawPanels[2].setPanelBackground(swapColor);
				modellerStack.repaintDrawPanels();
			}
		}
	}

	public void mouseReleased(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseEntered(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseExited(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}
}
