/*
Interface-name: CadObject.java, part of the 'Java-Simulation-Environment'

The 'Java-Simulation-Environment' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package interfaces;

import java.awt.Color;
import java.awt.Shape;
import java.util.Vector;

public interface CadObject
{
	public int	 	getGeometryTyp();
	public void   	setGeometryTyp(int geometryTyp);
	public int    	getLayerID();
	public void  	setLayerID(int layerID);
	public int 	  	getLineTyp();
	public void  	setLineTyp(int lineTyp);
	public int		getObjectId();
	public void		setObjectId(int id);
	public int		getNumberOfPoints();
	public void		setNumberOfPoints(int numberOfPoints);
	public int 		getCurrentPointNumber();
	public void 	setCurrentPointNumber(int currentPointNumber);
	public int		getExtrudingDirection();
	public void		setExtrudingDirection(int extrudingDirection);
	public int		getBuiltInView();
	public void		setBuiltInView(int builtInView);

	public double 	getLineWidth();
	public void   	setLineWidth(double lineTyp);
	public double	getTransparency();
	public void		setTransparency(double transparency);
	public double	getExtrusionStart();
	public void		setExtrusionStart(double extrusion);
	public double	getExtrusionStop();
	public void		setExtrusionStop(double extrusion);

	public void		setVertexList(Vector<Vertex> vertexList);
	public Vector<Vertex> getVertexList();

	public void		setObjectPoints(int pointNumber, double x1, double y1, double z1, double x2, double y2, double z2, double scale);

	public boolean	isVisible();
	public void		setVisible(boolean visible);
	public boolean	isFillable();
	public void		setFillable(boolean visible);
	public boolean	isFilled();
	public void		setFilled(boolean filled);
	public boolean	isInBuildProcess() ;
	public void		setInBuildProcess(boolean inBuildProcess);
	public boolean	isNewObject();
	public void		setNewObject(boolean newObject);
	public boolean  isRendered2D();
	public void		setRendered2D(boolean rendered2D);

	public Color	getFillColor();
	public void		setFillColor(Color fillColor);
	public Color	getLineColor();
	public void		setLineColor(Color lineColor);

	public Shape 	initShape(int panelID, double scale);
	public Shape	getShape(int panelID);
	public Shape	getShape(int panelID, double scale);
	public void		setShape(Shape shape);
	public Shape	getShapeXY();
	public Shape	getShapeXZ();
	public Shape	getShapeZY();

	public String	getName();
	public void		setName(String name);

	public void		finalizeObject(int view);

	public String	toString();
}
