/*
Class-name: ModellerStack.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller;

//import SimpleLine;

import gui.MyMenu;
import interfaces.CadObject;
import interfaces.ExportImportObject;
import interfaces.GuiInterface;
import interfaces.Layer;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JPanel;

import modeller.draw.HotSpot;
import modeller.layer.EditLayerProperties;
import modeller.layer.LayerFrame;
import modeller.layer.LayerPanel;
import modeller.objects.Objects;
import modeller.objects.ObjectsPanel;
import modeller.objects.ObjectsPropertiesPanel;
import modeller.toolBars.ViewBar;
import modeller.tools.ImportUrlClass;

public class ModellerStack
{
	// Objects needed for the drawing-process
	public Objects objects;
	public Vector<Layer> layers = new Vector<Layer>();
	public final ArrayList<CadObject> cadObjects = new ArrayList<CadObject>();	//	public final Vector<CadObject> cadObjects = new Vector<CadObject>();
	public final ArrayList<HotSpot> hotSpots = new ArrayList<HotSpot>();		//	public final Vector<HotSpot> hotSpots = new Vector<HotSpot>();
	public final ImportUrlClass importUrlClass = new ImportUrlClass(this);
	
	public String imageIconNames = "";			// Namelist of the imageicons for the graphial-objects 
	public String exportFormatNames = "";		// Namelist of the export-formats
	public String importFormatNames = "";		// Namelist of the export-formats
	public String simulatorClassesNames = "";	// Namelist of the simulator-classes
	
	public int selectedObject = -1;
	public int currentDrawPanelID = 0;
	public int currentObjectPanelID = 0;
	
	public CadObject currentCadObject;
	
	public boolean selectionToolButtonPressed = false;
	public boolean pointFixed = false;
	public boolean stillBuilding = false;
	public boolean objectMoving = false;
	public boolean objectStretching = false;
	
	public DrawPanel[] drawPanels = new DrawPanel[3];
	public EditLayerProperties[] editLayerProperties = new EditLayerProperties[2];
	public JPanel drawPanelContainer = null;

	public Double boundaryWidth = 800d, boundaryHeight = 800d, boundaryDepth = 800d, rasterWidth = 50d, pixelPerMm = 1d;
	public double globalScale = 1d;
//	public double panelClipX = 0, panelClipY = 0, panelClipWidth = 0, panelClipHeight = 0;
//	public double masterScale = 1d;

	public JButton swapButton;
	
	// Other objects, needed for steering the GUI
	public ObjectsPanel objectsPanel = null;
	public ObjectsPropertiesPanel objectsProperties = null;
	public final LayerPanel[] layerPanel = new LayerPanel[2];
	public LayerFrame layerFrame = null;
	public ModellerPanel modellerPanel = null;
	public MyMenu myMenu = null;
	public ViewBar viewBar = null;
	public String currentCadPath = "";
	public HashMap<String, ExportImportObject> simulatorObject = new HashMap<String, ExportImportObject>();
	public final HashMap<String, GuiInterface> guiObjects = new HashMap<String, GuiInterface>();
	
	// Flags for Mouse-Events
	public boolean mousePressed;
	public boolean mouseDragged;
	public boolean mouseEntered;
	public boolean mouseReleased;
	public boolean mouseExited;
	public boolean mouseMoved;
	
	// Flags for Component-Events
	public boolean componentResized;
	
	public int xPressed, yPressed, zPressed;
	public int xReleased, yReleased, zReleased;
	public int xMoved, yMoved, zMoved;
	public int xDragged, yDragged, zDragged;
	public int xFixed, yFixed, zFixed;
	
	public int componentWidth, componentHeight;
	
	/**
	 * Repainting all draw-panels
	 *
	 */
	public void repaintDrawPanels()
	{
		drawPanels[0].repaint();
		drawPanels[1].repaint();
		drawPanels[2].repaint();
	}
	
	/**
	 * Setting the Mouse-Flags
	 * @param mousePressed
	 * @param mouseDragged
	 * @param mouseEntered
	 * @param mouseReleased
	 * @param mouseExited
	 * @param mouseMoved
	 */
	public void setMouseFlags(boolean mousePressed, boolean mouseDragged, boolean mouseEntered, boolean mouseReleased, boolean mouseExited, boolean mouseMoved)
	{
		this.mousePressed = mousePressed;
		this.mouseDragged = mouseDragged;
		this.mouseEntered = mouseEntered;
		this.mouseReleased = mouseReleased;
		this.mouseExited = mouseExited;
		this.mouseMoved = mouseMoved;
	}
	
	/**
	 * Setting the Components-Flags
	 * @param componentResized
	 */
	public void setComponentFlags(boolean componentResized)
	{
		this.componentResized = componentResized;
	}

	public CadObject getCurrentCadObject() {
		return currentCadObject;
	}

	public void setCurrentCadObject(CadObject currentFemObject) {
		this.currentCadObject = currentFemObject;
	}
}
