/*
Class-name: Raster.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.draw;

import java.awt.Color;
import java.awt.Shape;
import java.awt.geom.GeneralPath;
import java.awt.geom.Rectangle2D;

import modeller.ModellerStack;

public class Raster
{
	private ModellerStack modellerStack;
	private Shape rasterShape;				// the shape with the raster in it
	private GeneralPath p;
	private Color color = Color.GRAY;	// color of the raster
	
	public Raster(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		
		rasterShape = generateRaster(modellerStack.boundaryWidth, modellerStack.boundaryHeight);
	}
	
	/**
	 * Generating the new raster
	 * @return
	 */
	public Shape generateRaster(double panelWidth, double panelHeight)
	{
		p = new GeneralPath();
		for(float i=0; i<=panelHeight; i+=modellerStack.rasterWidth) {
			p.moveTo(0f , (float)(i / modellerStack.pixelPerMm));
			p.lineTo((float)(panelWidth / modellerStack.pixelPerMm), (float)(i / modellerStack.pixelPerMm));
		}
		
		for(float i=0; i<=panelWidth; i+=modellerStack.rasterWidth) {
			p.moveTo((float)(i / modellerStack.pixelPerMm), 0f);
			p.lineTo((float)(i / modellerStack.pixelPerMm), (float)(panelHeight / modellerStack.pixelPerMm));
		}

		rasterShape = p;

		return rasterShape;
	}

	/**
	 * Generating the background for the painting-raster
	 * @param color
	 * @return
	 */
	public Shape generateBackground()
	{
		return (Shape)(new Rectangle2D.Double(0.0d, 0.0d, modellerStack.boundaryWidth, modellerStack.boundaryHeight));
	}
	
	public Color getColor() {
		return color;
	}

	public void setColor(Color color) {
		this.color = color;
	}

	public Shape getRasterShape() {
		return rasterShape;
	}

	public void setRasterShape(Shape raster) {
		this.rasterShape = raster;
	}

//	public float getRasterHeight() {
//		return rasterHeight;
//	}
//
//	public void setRasterHeight(float rasterHeight) {
//		this.rasterHeight = rasterHeight;
//	}
//
//	public float getRasterWidth() {
//		return rasterWidth;
//	}
//
//	public void setRasterWidth(float rasterWidth) {
//		this.rasterWidth = rasterWidth;
//	}
}
