package modeller.draw;
/*
Class-name: SimpleEllipse.java. Object-Plugin for the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

import interfaces.Vertex;

import java.awt.Shape;
import java.awt.geom.Rectangle2D;
import java.util.Vector;

public class StrechingRectangle
{
	/**
	 * @param panelID Parameter is [0-2]. Shows, which panel-view is activ. Needed for the front-, top- or side-view. 
	 */
	public static Shape getRectangle(double x1, double y1, double x2, double y2, int panelID, double scale)
	{	
		Shape shape;

		if(x1 <= x2 && y1 <= y2)
			shape = new Rectangle2D.Double(x1, y1, x2-x1, y2-y1);
		else if(x1 > x2 && y1 <= y2)
			shape = new Rectangle2D.Double(x2, y1, x1-x2, y2-y1);
		else if(x1 <= x2 && y1 > y2)
			shape = new Rectangle2D.Double(x1, y2, x2-x1, y1-y2);
		else // x1 > x2 && y1 > y2
			shape = new Rectangle2D.Double(x2, y2, x1-x2, y1-y2);
		
		return shape;
	}
	
	public static void buildNewSize(Vector<Vertex> vertexList, int panelID, double dw, double dh)
	{
		Vertex vertex;
		double xMin, yMin, zMin;
		
		vertex = vertexList.get(0);
		
		// Searching the minimum-values of x, y & z
		xMin = vertex.getX();
		yMin = vertex.getY();
		zMin = vertex.getZ();
		
		for(int i=1; i<vertexList.size(); i++) {
			vertex = vertexList.get(i);
			
			if(vertex.getX()<xMin) xMin = vertex.getX(); 
			if(vertex.getY()<yMin) yMin = vertex.getY(); 
			if(vertex.getZ()<zMin) zMin = vertex.getZ(); 
		}
		// Searching the minimum-values of x, y & z - END
			
			for(int i=0; i<vertexList.size(); i++) {
			vertex = vertexList.get(i);
			
			if(panelID==0) {
				vertex.setX(vertex.getX() + (vertex.getX()-xMin)*dw );
				vertex.setY(vertex.getY() + (vertex.getY()-yMin)*dh );

//				vertex.setX(vertex.getX() + (vertex.getX()-xMin)*dw );
//				vertex.setY(vertex.getY() + (vertex.getY()-yMin)*dh );
			}
			else if(panelID==1) {
				vertex.setZ(vertex.getZ()*dw);
				vertex.setY(vertex.getY()*dh);
			}
			else {
				vertex.setX(vertex.getX()*dw);
				vertex.setZ(vertex.getZ()*dh);
			}
		}
	}
}
