package modeller.layer;

import interfaces.Layer;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.util.Vector;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.border.EmptyBorder;

import modeller.ModellerStack;

public class EditLayerProperties extends JPanel implements ActionListener, FocusListener
{
	private ModellerStack modellerStack;
	
	private Layer layer;
	private int layerPanelID;
	private JPanel centerPanel = new JPanel();
	private JPanel northPanel = new JPanel();
	private Vector<JPanel> propertiesContainerPanels = new Vector<JPanel>(); 
	
	private JButton addProp, delProp;
	private int lastGainedFocus = -1;

	public EditLayerProperties(ModellerStack modellerStack, int layerPanelID)
	{
		this.modellerStack = modellerStack;
		this.layerPanelID = layerPanelID;
		
//		modellerStack.editLayerProperties = this;
		
		this.setLayout(new BorderLayout());
		
		if(layerPanelID==1)
			this.setBorder(BorderFactory.createTitledBorder("Edit properties "));
		
		initComponents();
	}
	
	private void initComponents()
	{
//		this.add(new JLabel("test"));
		
//		Box hBox = Box.createHorizontalBox();
		addProp = new JButton("Add property"); addProp.setName("addProp"); addProp.addActionListener(this);
		northPanel.add(addProp);
//		delProp = new JButton("Delete Property"); delProp.setName("delProp"); delProp.addActionListener(this);
//		northPanel.add(delProp);

//		centerPanel.add(new JLabel("test"));
//		centerPanel.setLayout(new BoxLayout(centerPanel, BoxLayout.Y_AXIS));
		
		this.add(northPanel, BorderLayout.NORTH);
		this.add(new JScrollPane(centerPanel), BorderLayout.CENTER);
		
	}

	public void setLayer(Layer layer)
	{
		this.layer = layer;
	}
	
	/**
	 * Adding a layer-property
	 *
	 */
	public void paintLayerProperty()
	{
		layer = modellerStack.layerPanel[0].getLayer();
		
		centerPanel.setVisible(false);
		centerPanel.removeAll();
		
		propertiesContainerPanels.clear();
				
		JTextField textField;
		JButton button;
		JPanel swapPanel = new JPanel();
		Box hBox;
		Box vBox;
		vBox = Box.createVerticalBox();
		hBox = Box.createHorizontalBox();
		
		Layer.LayerProperty layerProp;
		
		for(int i=0; i<layer.getLayerProperties().size(); i++) {
			layerProp = layer.getLayerProperties().get(i);
			swapPanel = new JPanel();
			hBox = Box.createHorizontalBox();	// Container for the properties-components
			// Textfield for the name of the property
			textField = new JTextField(layerProp.getPropertyName());
			textField.setName("name_"+i);
			textField.setPreferredSize(new Dimension(100, 20));
			textField.addActionListener(this);
			textField.addFocusListener(this);
			hBox.add(textField);
			// Textfield for the property-value
			textField = new JTextField(layerProp.getPropertyValue());
			textField.setName("value_"+i);
			textField.setPreferredSize(new Dimension(150, 20));
			textField.addActionListener(this);
			textField.addFocusListener(this);
			hBox.add(textField);
			// Deletebutton
			button = new JButton(new ImageIcon("images/icons/16x16/user-trash-full.png"));
			button.addActionListener(this);
			button.setBorder(new EmptyBorder(0, 0, 0, 0));
			button.setName("delete_"+i);
			hBox.add(new JLabel("  "));
			hBox.add(button);
			swapPanel.add(hBox);
			propertiesContainerPanels.add(swapPanel);
		}
		
		for(int i=0; i<propertiesContainerPanels.size(); i++) {
			vBox.add(propertiesContainerPanels.get(i));
		}
		
		centerPanel.add(vBox);
		

		centerPanel.setVisible(true);
	}
	
	public void actionPerformed(ActionEvent e)
	{
//		System.out.println(e.getActionCommand());
		
		Object object = e.getSource();
		String name = null;
		
		if(object instanceof JButton) {
			name = ((JButton)object).getName();
			if(object==addProp) {
				layer.addNewProperty("Property_"+layer.getLayerProperties().size(), "Property value(s)");
				modellerStack.editLayerProperties[0].paintLayerProperty();
				modellerStack.editLayerProperties[1].paintLayerProperty();
//				paintLayerProperty();
			}
			else if(object==delProp) {
				
			}
			else if(name!=null && name.indexOf("delete_")>=0) {
				Integer id = new Integer(name.split("_")[1]);
				System.out.println("delete property: "+id);
				layer.removeProperty(id);
				modellerStack.editLayerProperties[0].paintLayerProperty();
				modellerStack.editLayerProperties[1].paintLayerProperty();
//				paintLayerProperty();
			}
		}
		else if(object instanceof JTextField) {
			
			JTextField textField = (JTextField)e.getSource();
			
			String fieldTyp = textField.getName().split("_")[0];
			Integer id = new Integer(textField.getName().split("_")[1]);
			
			if(fieldTyp.equals("name")) {
				layer.getLayerProperties().get(id).setPropertyName(textField.getText());
//				modellerStack.editLayerProperties[0].paintLayerProperty();
//				modellerStack.editLayerProperties[1].paintLayerProperty();
			}
			else if(fieldTyp.equals("value")) {
				layer.getLayerProperties().get(id).setPropertyValue(textField.getText());
//				modellerStack.editLayerProperties[0].paintLayerProperty();
//				modellerStack.editLayerProperties[1].paintLayerProperty();
			}
		}
	}

	public void focusGained(FocusEvent e)
	{
		Object object = e.getSource();
		
		if(object instanceof JTextField) {
			
			JTextField textField = (JTextField)e.getSource();
			
			String fieldTyp = textField.getName().split("_")[0];
			Integer id = new Integer(textField.getName().split("_")[1]);
			lastGainedFocus = id;
			
			if(lastGainedFocus>=0)
				propertiesContainerPanels.get(lastGainedFocus).setBackground(Color.WHITE);
			
			if(fieldTyp.equals("name")) {
				layer.getLayerProperties().get(id).setPropertyName(textField.getText());
				if(layerPanelID==0)
					modellerStack.editLayerProperties[1].paintLayerProperty();
				else
					modellerStack.editLayerProperties[0].paintLayerProperty();
			}
			else if(fieldTyp.equals("value")) {
				layer.getLayerProperties().get(id).setPropertyValue(textField.getText());
				if(layerPanelID==0)
					modellerStack.editLayerProperties[1].paintLayerProperty();
				else
					modellerStack.editLayerProperties[0].paintLayerProperty();
			}
		}
	}

	public void focusLost(FocusEvent e)
	{
		Object object = e.getSource();

		if(object instanceof JTextField) {

			JTextField textField = (JTextField)e.getSource();

			String fieldTyp = textField.getName().split("_")[0];
			Integer id = new Integer(textField.getName().split("_")[1]);

			propertiesContainerPanels.get(id).setBackground(this.getBackground());

			if(fieldTyp.equals("name")) {
				layer.getLayerProperties().get(id).setPropertyName(textField.getText());
				if(layerPanelID==0)
					modellerStack.editLayerProperties[1].paintLayerProperty();
				else
					modellerStack.editLayerProperties[0].paintLayerProperty();
			}
			else if(fieldTyp.equals("value")) {
				layer.getLayerProperties().get(id).setPropertyValue(textField.getText());
				if(layerPanelID==0)
					modellerStack.editLayerProperties[1].paintLayerProperty();
				else
					modellerStack.editLayerProperties[0].paintLayerProperty();
			}
		}
	}
}
