/*
Class-name: LayerFrame.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/
package modeller.layer;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JFrame;

import modeller.ModellerStack;

public class LayerFrame extends JFrame
{
	private ModellerStack modellerStack;
	private LayerPanel layerPanel;
	private EditLayerProperties[] editLayerProperties = new EditLayerProperties[2];
	
	public LayerFrame(ModellerStack modellerStack, LayerPanel layerPanel)
	{
		this.modellerStack = modellerStack;
		this.layerPanel = layerPanel;
		
		editLayerProperties[0] = new EditLayerProperties(modellerStack, 0);
		editLayerProperties[1] = new EditLayerProperties(modellerStack, 1);
		
		modellerStack.editLayerProperties[0] = editLayerProperties[0];
		modellerStack.editLayerProperties[1] = editLayerProperties[1];

		editLayerProperties[0].setLayer(modellerStack.layerPanel[0].getLayer());
		
		layerPanel.setPreferredSize(new Dimension(280,280));
		
		this.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
		this.setSize(600, 360);
		this.setTitle("Editing the layers");
		this.setAlwaysOnTop(true);
		this.setLayout(new BorderLayout());
		this.getContentPane().add(layerPanel, BorderLayout.WEST);
		this.getContentPane().add(editLayerProperties[1], BorderLayout.CENTER);
	}
	
	public void setVisible(boolean visible)
	{
//		System.out.println("setVisible");
		
		layerPanel.updateLayer(modellerStack.layerPanel[0].getLayer().getLayerID());
		super.setVisible(visible);
	}
}
