/*
Class-name: LayerPanel.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.layer;

import interfaces.Layer;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.JSpinner;
import javax.swing.JTextField;
import javax.swing.SpinnerListModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import modeller.ModellerStack;
import static modeller.tools.StaticMethods.resetPaintBit;
import static modeller.tools.StaticMethods.updateLayerdata;

public class LayerPanel extends JPanel implements ActionListener, MouseListener, ChangeListener
{
	private ModellerStack modellerStack;
	
	 private final int X_DIRECTION = 0;
	 private final int Y_DIRECTION = 1;
	 private final int Z_DIRECTION = 2;

	private int layerPanelID;
	private JComboBox cbLayer, lineTyp, lineWidth;
	private JSpinner extrudeDirection;
	private JTextField layerName, layerID, lineColor, fillColor, extrusionStart, extrusionStop;
	private ImageIcon[] iIcon = { new ImageIcon("images/lineIcon.png", "Line"), new ImageIcon("images/fineDashedLineIcon.png", "Dashed line") };
	private Double[] lines = { new Double(1.0), new Double(1.5), new Double(2.0), new Double(2.5), new Double(3), new Double(4.0), new Double(5.0) };
	private Layer layer;
	private JLabel transparencylabel;
	private JButton button;
	private boolean isEditlayerPanel = false;
	private JSlider transparencySlider = null;
	
	private Dimension lSize = new Dimension(70, 20); 
	private Dimension tfSize = new Dimension(145, 20);
	private Dimension fullSize = new Dimension(260, 20);
	
	public LayerPanel(ModellerStack modellerStack, boolean isEditlayerPanel, int layerPanelID)
	{
		this.modellerStack = modellerStack;
		this.isEditlayerPanel = isEditlayerPanel;
		this.layerPanelID = layerPanelID;
		
		layer = modellerStack.layers.get(0);
		
		if(layerPanelID==1) {
			this.setPreferredSize(new Dimension(260, 100));
			this.setMinimumSize(new Dimension(260, 100));
			this.setMaximumSize(new Dimension(260, 100));
			this.setBorder(BorderFactory.createTitledBorder("Layer "));
		}
		else {
			this.setPreferredSize(new Dimension(295, 100));
			this.setMinimumSize(new Dimension(295, 100));
			this.setMaximumSize(new Dimension(295, 100));
			
		}
		
		updateLayer();
	}
	
	public void updateLayer(int layerID)
	{
		this.layer = modellerStack.layers.get(layerID);
		updateLayer();
	}
	public void updateLayer()
	{
		this.removeAll();

		Box vBox = Box.createVerticalBox();
		
		JPanel buttonPanel = new JPanel();	// buttonPanel.setLayout(new GridLayout(1, 2));
		buttonPanel.setPreferredSize(new Dimension(225, 20)); // new Dimension(180, 20));	
		if(!isEditlayerPanel) {
			buttonPanel.setLayout(new GridLayout(1, 3));
		}
		else {
			buttonPanel.setLayout(new GridLayout(1, 2));
		}
		
		button = new JButton("Add"); button.setName("addLayer"); button.addActionListener(this);
		buttonPanel.add(button);
		button = new JButton("Delete"); button.setName("deleteLayer"); button.setEnabled(false); button.addActionListener(this);
		buttonPanel.add(button);
		if(!isEditlayerPanel) {
			button = new JButton("Edit"); button.setName("editLayer"); button.addActionListener(this);
			buttonPanel.add(button);
		}
		
		vBox.add(buttonPanel);
		vBox.add(Box.createVerticalStrut(4));
		
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateCBLayer());
		vBox.add(Box.createVerticalStrut(8));
		vBox.add(updateLayerID());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(initExtrudeDirection());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateExtrusionStart());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateExtrusionStop());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateLayerName());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateLineTyp());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateLineWidth());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateLineColor());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateFillColor());
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(updateTransparency());
		
		this.add(vBox);

		this.setVisible(false);
		this.setVisible(true);
		
		if(modellerStack.editLayerProperties[0]!=null) {
			modellerStack.editLayerProperties[0].paintLayerProperty();
			modellerStack.editLayerProperties[1].paintLayerProperty();
		}
	}
	
	private JComboBox updateCBLayer()
	{
		String[] cbStr = new String[modellerStack.layers.size()];
		
		for(int i=0; i < modellerStack.layers.size(); i++)
			cbStr[i] = modellerStack.layers.get(i).getName();
		
		cbLayer = new JComboBox(cbStr);
		cbLayer.setSelectedIndex(layer.getLayerID());
		cbLayer.setName("cbLayer");
		cbLayer.addActionListener(this);
		cbLayer.setBackground(Color.WHITE);
		cbLayer.setPreferredSize(fullSize);
		
		cbLayer.setVisible(false);
		cbLayer.setVisible(true);

		return cbLayer;
	}
	
	private Box updateLayerName()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Name: "); label.setPreferredSize(lSize);
		layerName = new JTextField(""+layer.getName());
		layerName.addActionListener(this);
		layerName.setName("layerName");
		layerName.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(layerName);
		
		return hBox;
	}
	
	private Box updateLayerID()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Layer-ID: "); label.setPreferredSize(lSize);
		layerID = new JTextField(""+layer.getLayerID());
		layerID.setEditable(false);
		layerID.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(layerID);
		
		return hBox;
	}

	private Box updateLineTyp()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Line-Typ: "); label.setPreferredSize(lSize);

		lineTyp = new JComboBox(iIcon);
		lineTyp.setBackground(Color.WHITE);
		lineTyp.addActionListener(this);
		lineTyp.setName("lineTyp");
		lineTyp.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(lineTyp);
		
		return hBox;
	}
	
	private Box updateLineWidth()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Line-Width: "); label.setPreferredSize(lSize);

		lineWidth = new JComboBox(lines);
		lineWidth.setSelectedItem(layer.getLineWidth());
		lineWidth.setBackground(Color.WHITE);
		lineWidth.addActionListener(this);
		lineWidth.setName("lineWidth");
		lineWidth.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(lineWidth);
		
		return hBox;
	}

	private Box updateLineColor()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Line-Color: "); label.setPreferredSize(lSize);
		lineColor = new JTextField("");
		lineColor.setBackground(layer.getLineColor());
		lineColor.addMouseListener(this);
		lineColor.setName("lineColor");
		lineColor.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(lineColor);
		
		return hBox;
	}

	private Box updateFillColor()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Fill-Color: "); label.setPreferredSize(lSize);
		fillColor = new JTextField("");
		fillColor.setBackground(layer.getFillColor());
		fillColor.addMouseListener(this);
		fillColor.setName("fillColor");
		fillColor.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(fillColor);
		
		return hBox;
	}

	private JPanel updateTransparency()
	{
		JPanel swapPanel = new JPanel();
		swapPanel.setLayout(new GridLayout(2, 1));
//		swapPanel.setBackground(Color.WHITE);

		transparencySlider = new JSlider(0, 10);
//		transparencySlider.setBackground(Color.WHITE);
		transparencySlider.setName("transparencySlider");
		transparencySlider.setValue((int)(layer.getTransparency()*10));
		transparencySlider.setToolTipText("Transparency");
		transparencySlider.setPaintLabels(true);
		transparencySlider.setPaintTrack(true);
		transparencySlider.setPaintTicks(true);
		transparencySlider.setMinorTickSpacing(1);
		transparencySlider.addChangeListener(this);
		transparencySlider.setPreferredSize(tfSize); transparencySlider.setMaximumSize(tfSize);

		transparencylabel = new JLabel("Transparency: "+(layer.getTransparency()+"   ").substring(0, 3));
		transparencylabel.setPreferredSize(tfSize); transparencylabel.setMaximumSize(tfSize);

		swapPanel.add(transparencylabel);
		swapPanel.add(transparencySlider);
		
		return swapPanel;
	}

	private Box updateExtrusionStart()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Start extr.: "); label.setPreferredSize(lSize);
		extrusionStart = new JTextField(""+layer.getExtrusionStart());
		extrusionStart.setBackground(Color.WHITE);
		extrusionStart.addActionListener(this);
		extrusionStart.setName("extrusionStart");
		extrusionStart.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(extrusionStart);
		
		return hBox;
	}

	private Box updateExtrusionStop()
	{
		Box hBox = Box.createHorizontalBox();
		JLabel label = new JLabel("Stop extr.: "); label.setPreferredSize(lSize);
		extrusionStop = new JTextField(""+layer.getExtrusionStop());
		extrusionStop.setBackground(Color.WHITE);
		extrusionStop.addActionListener(this);
		extrusionStop.setName("extrusionStop");
		extrusionStop.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(extrusionStop);
		
		return hBox;
	}
	
	private Box initExtrudeDirection()
	{
		Box hBox = Box.createHorizontalBox();
		
		String[] string = { "x", "y", "z" };
		
		JLabel label = new JLabel("Extrude: "); label.setPreferredSize(lSize);
		
		extrudeDirection = new JSpinner(new SpinnerListModel(string));
		switch(layer.getExtrudingDirection()) {
			case 0:
				extrudeDirection.setValue("x");
				break;
			case 1:
				extrudeDirection.setValue("y");
				break;
			case 2:
				extrudeDirection.setValue("z");
				break;
				
		}
		
		extrudeDirection.addChangeListener(this);
		extrudeDirection.setPreferredSize(tfSize);
		
		hBox.add(label);
		hBox.add(extrudeDirection);
		
		return hBox;
	}

	public JComboBox getCbLayer() {
		return cbLayer;
	}

	public Layer getLayer() {
		return layer;
	}

	public void setLayer(Layer layer) {
		this.layer = layer;
	}

	public void actionPerformed(ActionEvent e)
	{
		Object object = e.getSource();
		String name;
		
		if(object instanceof JTextField) {
			JTextField tf = (JTextField)object;
			name = tf.getName();

			if(name.equals("layerName")) {
				System.out.println("layerName: "+layer.getName());
				layer.setName(tf.getText().replaceAll(":", ""));
//				System.out.println("layerName: "+layer.getName());
			}
			else if(name.equals("extrusionStart")) {
				layer.setExtrusionStart(new Double(tf.getText()).doubleValue());
//				System.out.println("extrusionStart: "+layer.getExtrusionStart());
				updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
				resetPaintBit(modellerStack.cadObjects, layer.getLayerID());
			}
			else if(name.equals("extrusionStop")) {
				layer.setExtrusionStop(new Double(tf.getText()).doubleValue());
//				System.out.println("extrusionStop: "+layer.getExtrusionStop());
				updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
				resetPaintBit(modellerStack.cadObjects, layer.getLayerID());
			}
		} else if(object instanceof JButton) {
			JButton bt = (JButton)e.getSource();
			modellerStack.myMenu.layerEventPerformed(bt.getName());
		}
		
		if(object instanceof JComboBox) {
			JComboBox cb = (JComboBox)object;
			name = cb.getName();
			System.out.println(cb.getSelectedItem());
			if(name.equals("lineWidth")) {
				layer.setLineWidth((Double)cb.getSelectedItem());
			}
			else if(name.equals("cbLayer")) {
				layer = modellerStack.layers.get(cb.getSelectedIndex());
				modellerStack.editLayerProperties[0].paintLayerProperty();
				modellerStack.editLayerProperties[1].paintLayerProperty();
			}
		}
		
		if(layerPanelID==0)
			modellerStack.layerPanel[1].getCbLayer().setSelectedIndex(modellerStack.layerPanel[0].getCbLayer().getSelectedIndex());
		else
			modellerStack.layerPanel[0].getCbLayer().setSelectedIndex(modellerStack.layerPanel[1].getCbLayer().getSelectedIndex());
		
		modellerStack.layerPanel[0].updateLayer();
		
		if(modellerStack.layerFrame.isVisible())
			modellerStack.layerPanel[1].updateLayer();

		updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
		modellerStack.repaintDrawPanels();
	}

	public void mouseClicked(MouseEvent e)
	{
		Object object = e.getSource();
		String name;
		
		if(object instanceof JTextField) {
			JTextField tf = (JTextField)object;
			name = tf.getName();
			System.out.println("name: "+name+" - "+tf.getText());
			if(name.equals("lineColor")) {
				Color swapColor = JColorChooser.showDialog(null, "Choose new fillcolor", layer.getLineColor());
				if(swapColor!=null)
					layer.setLineColor(swapColor);

				modellerStack.layerPanel[0].updateLayer();
				
				if(modellerStack.layerFrame.isVisible())
					modellerStack.layerPanel[1].updateLayer();
				
				updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
			}
			else if(name.equals("fillColor")) {
				Color swapColor = JColorChooser.showDialog(null, "Choose new fillcolor", layer.getFillColor());
				if(swapColor!=null)
					layer.setFillColor(swapColor);
				
				modellerStack.layerPanel[0].updateLayer();
				
				if(modellerStack.layerFrame.isVisible())
					modellerStack.layerPanel[1].updateLayer();

			}

			updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
			modellerStack.objectsProperties.updateObjectList(false);
			modellerStack.repaintDrawPanels();
		}
		
	}

	public void mouseEntered(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseExited(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mousePressed(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseReleased(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void stateChanged(ChangeEvent e) {

		if(e.getSource() instanceof JSlider) {
			if(((JSlider)e.getSource()).getName().equals("transparencySlider")) {
				layer.setTransparency(new Double(((JSlider)e.getSource()).getValue()).doubleValue() *0.1d);
				transparencylabel.setText("Transparency: "+(layer.getTransparency()+"   ").substring(0, 3));

				if(layerPanelID==0)
					modellerStack.layerPanel[1].getTransparencySlider().setValue(((JSlider)e.getSource()).getValue());
				else
					modellerStack.layerPanel[0].getTransparencySlider().setValue(((JSlider)e.getSource()).getValue());
				
				updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
				
				modellerStack.repaintDrawPanels();
			}
		} else if(e.getSource() instanceof JSpinner) {
			if(e.getSource()==extrudeDirection) {
				if(extrudeDirection.getValue().equals("x"))
					layer.setExtrudingDirection(X_DIRECTION);
				else if(extrudeDirection.getValue().equals("y"))
					layer.setExtrudingDirection(Y_DIRECTION);
				else if(extrudeDirection.getValue().equals("z"))
					layer.setExtrudingDirection(Z_DIRECTION);
			}
		}
	}

	public JSlider getTransparencySlider() {
		return transparencySlider;
	}
}
