/*
Class-name: ObjectsPropertiesPanel.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.objects;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import interfaces.CadObject;
import interfaces.Layer;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JToggleButton;

import modeller.ModellerStack;
import modeller.tools.StaticMethods;

public class ObjectsPropertiesPanel extends JPanel implements ActionListener
{
	private ModellerStack modellerStack;
	private CadObject cadObject = null;
	private JTextField objectID, name;
	private JComboBox layerID;
	private JCheckBox visible, filled;
	private JPanel layerIDPanel;
	private JLabel filledLabel;
	private Box filledHBox;
	
	Dimension lSize = new Dimension(75, 20); 
	Dimension tfSize = new Dimension(90, 20); 
	
	public ObjectsPropertiesPanel(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		
		modellerStack.objectsProperties = this;
		
		this.setBackground(Color.WHITE);
		this.setBorder(BorderFactory.createTitledBorder("Properties "));
		initObjectList();

	}
	
	public void initObjectList()
	{
		System.out.println("initObjectList");
		
//		this.setVisible(false);
//		this.removeAll();

		Box vBox = Box.createVerticalBox();
		Box hBox;
		JPanel hPanel;
		JLabel label;
		
		hBox = Box.createHorizontalBox();
		label = new JLabel("Object-ID:"); label.setPreferredSize(lSize);
		objectID = new JTextField(""); objectID.setEditable(false);
		objectID.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(objectID);
		vBox.add(hBox);
		
		hBox = Box.createHorizontalBox();
		label = new JLabel("Name:"); label.setPreferredSize(lSize);
		name = new JTextField("");
		name.setName("name");
		name.addActionListener(this);
		name.setPreferredSize(tfSize);
		hBox.add(label);
		hBox.add(name);
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(hBox);

		hBox = Box.createHorizontalBox();
		hPanel = new JPanel(); hPanel.setPreferredSize(tfSize); hPanel.setLayout(new GridLayout(1,1));
		label = new JLabel("Visible:"); label.setPreferredSize(lSize);
		visible = new JCheckBox("", false);	 visible.setName("isVisible");
		visible.setBackground(Color.WHITE);
		visible.setPreferredSize(tfSize);
		visible.addActionListener(this);
		hPanel.add(visible);
		hBox.add(label);
		hBox.add(hPanel);
//		vBox.add(Box.createVerticalStrut(2));
		vBox.add(hBox);
		
		filledHBox = Box.createHorizontalBox();
		hPanel = new JPanel(); hPanel.setPreferredSize(tfSize); hPanel.setLayout(new GridLayout(1,1));
		filledLabel = new JLabel("Filled:"); filledLabel.setPreferredSize(lSize);
		filled = new JCheckBox("", false);	filled.setName("isFilled"); filled.setEnabled(false);
		filled.setBackground(Color.WHITE);
		filled.setPreferredSize(tfSize);
		filled.addActionListener(this);
		hPanel.add(filled);
		filledHBox.add(filledLabel);
		filledHBox.add(hPanel);
//		vBox.add(Box.createVerticalStrut(2));
		vBox.add(filledHBox);

		hBox = Box.createHorizontalBox();
		label = new JLabel("Layer-ID:"); label.setPreferredSize(lSize);
		layerID = new JComboBox();
		layerID.setPreferredSize(tfSize);
		layerID.setName("layerID");
		hBox.add(label);
		hBox.add(layerID);
		vBox.add(Box.createVerticalStrut(2));
		vBox.add(hBox);

		this.add(vBox);
	}

	
	public void updateObjectList(boolean bool)
	{
		if(cadObject!=null) {
			updateObjectList(cadObject, bool);
		}
	}
	public void updateObjectList(CadObject cadObject, boolean bool)
	{
		this.cadObject = cadObject;
		
		if(cadObject.isFillable()) {
			filled.setEnabled(true);
			filledHBox.setVisible(true);
		}		
		else {
			filledHBox.setVisible(false);
		}
		
		objectID.setText(""+cadObject.getObjectId());

		name.setText(""+cadObject.getName());
		visible.setSelected(cadObject.isVisible());
		filled.setSelected(cadObject.isFilled());
		
		updateLayerCB();

		StaticMethods.updateLayerdata(modellerStack.cadObjects, modellerStack.layers);
//		updateLayerdata();
	}

	public void updateLayerCB()
	{
		layerID.removeActionListener(this);

		layerID.removeAllItems();
		for(int i=0; i<modellerStack.layers.size(); i++)
			layerID.addItem(modellerStack.layers.get(i).getName());

		if(modellerStack.cadObjects.size()>0)
			layerID.setSelectedIndex(cadObject.getLayerID());
		
		layerID.addActionListener(this);
}
	
//	public void updateLayerdata()
//	{
//		Layer layer = modellerStack.layers.get(cadObject.getLayerID());
//		
//		cadObject.setLineColor(layer.getLineColor());
//		cadObject.setFillColor(layer.getFillColor());
//		cadObject.setLineWidth(layer.getLineWidth());
//		cadObject.setLineTyp(layer.getLineTyp());
//		cadObject.setTransparency(layer.getTransparency());
//		cadObject.setExtrudingDirection(layer.getExtrudingDirection());
//		cadObject.setExtrusionStart(layer.getExtrusionStart());
//		cadObject.setExtrusionStop(layer.getExtrusionStop());
//	}
	
	public void actionPerformed(ActionEvent e)
	{
		Object object = e.getSource();
		
		if(object instanceof JCheckBox) {
			JCheckBox swap = (JCheckBox)object;
			
			if(object==visible) {
				cadObject.setVisible(swap.isSelected());
			} else if(object==filled) {
				cadObject.setFilled(swap.isSelected());
			}
			updateObjectList(cadObject, false);
		}
		else {
			if(object instanceof JComboBox) {		// ComboBox for selecting the line-width
				JComboBox swap = (JComboBox)object;
			
				if(object==layerID && modellerStack.cadObjects.size()>0) {
					cadObject.setLayerID(swap.getSelectedIndex());
					modellerStack.objectsPanel.updateObjectTree();
					updateObjectList(cadObject, true);
				}
			}
			else {
				if(object instanceof JTextField) {		// ComboBox for selecting the line-width
					JTextField tf = (JTextField)object;
					if(object==name) {
						cadObject.setName(tf.getText());
						updateObjectList(cadObject, false);						
					}
				}
			}
		}
		modellerStack.repaintDrawPanels();
	}
}
