package modeller.preview3d;

import java.awt.Color;
import java.awt.Transparency;
import java.util.ArrayList;

import interfaces.CadObject;
import interfaces.J3dObject;
import interfaces.Layer;

import javax.media.j3d.Appearance;
import javax.media.j3d.Material;
import javax.media.j3d.Shape3D;
import javax.media.j3d.Transform3D;
import javax.media.j3d.TransformGroup;
import javax.media.j3d.TransparencyAttributes;
import javax.vecmath.Color3f;
import javax.vecmath.Vector3d;
import javax.vecmath.Vector3f;

import com.sun.j3d.utils.geometry.Box;
import com.sun.j3d.utils.geometry.Cylinder;

public class J3dObjects // implements J3dObject
{
	public static class EmptyObject implements J3dObject
	{
		protected CadObject cadObject;
		protected Layer layer;
		
		protected Vector3f translation;
		
		protected float x1, y1, z1, x2, y2, z2;
		protected float dx, dy, dz;
		protected float r, g, b;
		protected int builtInView = 0;
		protected Double boundaryWidth = 800d, boundaryHeight = 800d, boundaryDepth = 800d, rasterWidth = 50d, pixelPerMm = 1d;

		public void setObjectData(CadObject cadObject, Layer layer)
		{
			this.cadObject = cadObject; this.layer = layer;

			builtInView = cadObject.getBuiltInView();
		}

		/**
		 * Setting the boundyries for the three views, the raster and the pixelresolution
		 */
		public void setBoundaries(Double boundaryWidth, Double boundaryHeight, Double boundaryDepth, Double rasterWidth, Double pixelPerMm)
		{
			this.boundaryWidth = boundaryWidth;
			this.boundaryHeight = boundaryHeight;
			this.boundaryDepth = boundaryDepth;
			this.rasterWidth = rasterWidth;
			this.pixelPerMm = pixelPerMm;
		}

		public String getName()
		{
			return cadObject.getName();
		}

		public TransformGroup getJ3dObject()
		{
			// TODO Auto-generated method stub
			return null;
		}

		public void initJ3dObject()
		{
			// TODO Auto-generated method stub		
		}
	}
	
	/**
	 *getting a circle/Cylinder-object
	 *
	 */
	public static class CircleObject extends EmptyObject
	{
		protected float radius, height = 0;

		public CircleObject(CadObject cadObject, Layer layer)
		{
			this.cadObject = cadObject; this.layer = layer;
			
			builtInView = cadObject.getBuiltInView();
		}

		public void initJ3dObject()
		{
			Color color = cadObject.getFillColor();
			
			double minOfDrawpanel;
			
			minOfDrawpanel = Math.min( boundaryDepth, Math.min(boundaryWidth, boundaryHeight) );
			
			r = (float)(color.getRed())   / 255f;
			g = (float)(color.getGreen()) / 255f;
			b = (float)(color.getBlue())  / 255f;

			// Getting the objectpoints
			x1 = (float)(cadObject.getVertexList().get(0).getX() / minOfDrawpanel);
			y1 = (float)(cadObject.getVertexList().get(0).getY() / minOfDrawpanel);
			z1 = (float)(cadObject.getVertexList().get(0).getZ() / minOfDrawpanel);
			x2 = (float)(cadObject.getVertexList().get(1).getX() / minOfDrawpanel);
			y2 = (float)(cadObject.getVertexList().get(1).getY() / minOfDrawpanel);
			z2 = (float)(cadObject.getVertexList().get(1).getZ() / minOfDrawpanel);
			
			// Calculating the differences 
			dx = x2 - x1;
			dy = y2 - y1;
			dz = z2 - z1;
			
//			System.out.println("x1: "+x1+" - y1: "+y1+" - z1: "+z1+" | x2: "+x2+" - y2: "+y2+" - z2: "+z2);
			
			// calculating the radius and the height
			radius = (float)Math.sqrt(dx*dx + dy*dy);
			height = (float)(Math.abs(layer.getExtrusionStop() - layer.getExtrusionStart()) / minOfDrawpanel);			
			if(height==0)
				height = 0.01f;
			
			// Setting the translation of the object
			translation = new Vector3f(x1, y1, z1);
		}

		public TransformGroup getJ3dObject()
		{
			initJ3dObject();
			
			TransformGroup tg = new TransformGroup();
			Appearance appearance = new Appearance();
			Transform3D t3d = new Transform3D();
			
			// Setting the material: Color-properties, reflection ...
			appearance.setMaterial(new Material(new Color3f(r, g, b), new Color3f(r*0.5f, g*0.5f, b*0.5f), new Color3f(r, g, b), new Color3f(r*0.75f, g*0.75f, b*0.75f), 64f));
			
			// Setting the rotation for the Cylinder-object
			if(builtInView==0)
				t3d.rotX(Math.toRadians(90d));
			else if(builtInView==1)
				t3d.rotZ(Math.toRadians(90d));
			else
				t3d.rotY(Math.toRadians(90d));

			// Setting the translation
			t3d.setTranslation(translation);

			// Setting the transparencyattribute, if neccessary
			System.out.println("cadObject.getTransparency(): "+cadObject.getTransparency());
			if(cadObject.getTransparency()<1d)
				appearance.setTransparencyAttributes(new TransparencyAttributes(TransparencyAttributes.NICEST, 1f - (float)cadObject.getTransparency()));
			
			tg.addChild(new Cylinder(radius, height, Cylinder.GENERATE_NORMALS, 40, 1, appearance));
			tg.setTransform(t3d);
			
			tg.setCapability(TransformGroup.ALLOW_CHILDREN_READ);
			tg.setCapability(TransformGroup.ALLOW_CHILDREN_WRITE);
			tg.setCapability(TransformGroup.ALLOW_CHILDREN_EXTEND);
			tg.setCapability(TransformGroup.ALLOW_TRANSFORM_READ);
			tg.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE);
			
			return tg;
		}
	}

	/**
	 * Getting a Java3d Box-object
	 */
	public static class BoxObject extends EmptyObject
	{
		public BoxObject(CadObject cadObject, Layer layer)
		{
			this.cadObject = cadObject; this.layer = layer;
		}
		
		public void initJ3dObject()
		{
			// TODO Auto-generated method stub			
		}
		
		public TransformGroup getJ3dObject()
		{
			// TODO Auto-generated method stub
			return null;
		}
	}

	/**
	 * Getting a Java3d Shape3D-object
	 */
	public static class Shape3dObject extends EmptyObject
	{
		public Shape3dObject(CadObject cadObject, Layer layer)
		{
			this.cadObject = cadObject; this.layer = layer;
		}
		
		public void initJ3dObject()
		{
			// TODO Auto-generated method stub
		}

		public TransformGroup getJ3dObject()
		{
			// TODO Auto-generated method stub
			return null;
		}
	}
}
