/*
Class-name: J3dPreview.class, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.preview3d;

import interfaces.CadObject;
import interfaces.J3dObject;
import interfaces.Layer;
import interfaces.Preview3D;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GraphicsConfiguration;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.ArrayList;
import java.util.Vector;

import javax.media.j3d.AmbientLight;
import javax.media.j3d.Background;
import javax.media.j3d.BoundingSphere;
import javax.media.j3d.BranchGroup;
import javax.media.j3d.Canvas3D;
import javax.media.j3d.DirectionalLight;
import javax.media.j3d.TransformGroup;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;
import javax.vecmath.Color3f;
import javax.vecmath.Point3d;
import javax.vecmath.Vector3f;

import modeller.ModellerPanel;

import com.sun.j3d.utils.behaviors.mouse.MouseRotate;
import com.sun.j3d.utils.behaviors.mouse.MouseTranslate;
import com.sun.j3d.utils.behaviors.mouse.MouseZoom;
import com.sun.j3d.utils.geometry.ColorCube;
import com.sun.j3d.utils.universe.SimpleUniverse;

public class J3dPreview extends JPanel implements Preview3D, ActionListener, MouseListener
{
	private ArrayList<CadObject> cadObjects;
	private Vector<Layer> layers;
	private ModellerPanel modellerPanel;
	
	private Double boundaryWidth = 800d, boundaryHeight = 800d, boundaryDepth = 800d, rasterWidth = 50d, pixelPerMm = 1d;
	
	ArrayList<J3dObject> j3dObjects = new ArrayList<J3dObject>();
	
	private SimpleUniverse simpleUniverse = null;
	private GraphicsConfiguration config = null;
	private Canvas3D canvas3d = null;
	private BranchGroup objRoot = null;
	private BranchGroup swapBG = null;
//	private TransformGroup objTrans = null;
	private TransformGroup swapTG = null;

	private BoundingSphere bigBounds = null;
	private DirectionalLight directionalLight = null;
	private DirectionalLight directionalLight2 = null;
	private AmbientLight ambientLight = null;
	private Background background = null;
	
	private OspRenderer ospRenderer = null;
	private ArrayList<J3dObject> j3dObjectList = new ArrayList<J3dObject>();
	
	private J3dPopup popup = null;
	
//	private int startNumberOfChildren = 0;
	
	public J3dPreview(ModellerPanel modellerPanel) // ArrayList<CadObject> cadObjects, Vector<Layer> layers)
	{
//		this.cadObjects = cadObjects;
//		this.layers = layers;
		this.modellerPanel = modellerPanel;
		
		popup = new J3dPopup(modellerPanel);

		float r, g, b;
		
		Color color = Color.LIGHT_GRAY;
		
		r = (float)(color.getRed())   / 255f;
		g = (float)(color.getGreen()) / 255f;
		b = (float)(color.getBlue())  / 255f;
		
		this.setLayout(new BorderLayout());
//		this.setLayout(new GridLayout(1,1));
		
		config 			= SimpleUniverse.getPreferredConfiguration();
		canvas3d 		= new Canvas3D(config); canvas3d.addMouseListener(this);
		simpleUniverse 	= new SimpleUniverse(canvas3d);
		objRoot 		= new BranchGroup();
//		swapBG			= new BranchGroup();
//		objTrans 		= new TransformGroup();
		bigBounds 		= new BoundingSphere(new Point3d(),1000000000);
		background 		= new Background( new Color3f(r, g, b) );
		
		background.setApplicationBounds(bigBounds);
		
		// This will move the ViewPlatform back a bit so the
        // objects in the scene can be viewed.
		simpleUniverse.getViewingPlatform().setNominalViewingTransform();
		
	    // Licht aus Richtung des Betrachters
        directionalLight = new DirectionalLight(new Color3f(1.0f, 1.0f, 1.0f), new Vector3f(0.0f, 0.0f, -1.0f)); 
        directionalLight.setInfluencingBounds(bigBounds);

        // Licht aus entgegengesetzter Richtung des Betrachters
        directionalLight2 = new DirectionalLight(new Color3f(1.0f, 1.0f, 1.0f), new Vector3f(0.0f, 0.0f, 1.0f)); 
        directionalLight2.setInfluencingBounds(bigBounds);
        
        // Mindest/Eigenreflektion !
        ambientLight = new AmbientLight(new Color3f(0.4f, 0.4f, 0.4f));
        ambientLight.setInfluencingBounds(bigBounds);
        
//        objTrans.addChild(new ColorCube(0.4));
        swapTG = getNewTransformGroup();
        swapTG.addChild(new CoordinatePlane().getPlane(new Vector3f(0.0f, 0.0f, 0.0f), 1.0f, 1));
        swapBG = getNewBranchGroup();
        swapBG.addChild(swapTG);
        mouseEvent(objRoot, swapTG, bigBounds);
        
        objRoot.addChild(swapBG);
        objRoot.addChild(background);
        objRoot.addChild(directionalLight);
        objRoot.addChild(directionalLight2);
        
        objRoot.setCapability(BranchGroup.ALLOW_CHILDREN_READ);
        objRoot.setCapability(BranchGroup.ALLOW_CHILDREN_WRITE);
        objRoot.setCapability(BranchGroup.ALLOW_CHILDREN_EXTEND);
        objRoot.setCapability(BranchGroup.ALLOW_DETACH);
        
        objRoot.compile();
        
        simpleUniverse.addBranchGraph(objRoot);
        
//        startNumberOfChildren = objRoot.numChildren();
        
        JPanel buttonPanel = new JPanel();
        JButton updateButton = new JButton("Update");	updateButton.addActionListener(this);
        JButton clearButton = new JButton("Clear");		clearButton.addActionListener(this);
        buttonPanel.add(updateButton);
        buttonPanel.add(clearButton);
        
        this.add(buttonPanel, BorderLayout.NORTH);
        
        this.add(canvas3d, BorderLayout.CENTER);
        this.setBorder(new BevelBorder(BevelBorder.LOWERED, Color.LIGHT_GRAY, Color.BLACK));
	}
	
	/**
	 * Einbinden der Zoom-, Rotations- und Schiebefunktionen von Java3D
	 * @param branchgroup
	 * @param transformgroup
	 * @param BigBounds
	 */
	private void mouseEvent(BranchGroup branchgroup, TransformGroup transformgroup, BoundingSphere BigBounds)
    {
        // --- Einbinden der Zoom-, Rotations- und Schiebefunktionen ---

		// Rotationsabfrage mit der Maus
        MouseRotate MouseCtrl1 = new MouseRotate(transformgroup);
        MouseCtrl1.setSchedulingBounds(BigBounds);
        branchgroup.addChild(MouseCtrl1);

        // Positionsabfrage der "Kamera" mit der Maus
        MouseTranslate MouseCtrl2 = new MouseTranslate(transformgroup);
        MouseCtrl2.setSchedulingBounds(BigBounds);
        branchgroup.addChild(MouseCtrl2);

        // Zoomabfrage mit der Maus
        MouseZoom MouseCtrl3 = new MouseZoom(transformgroup);
        MouseCtrl3.setSchedulingBounds(BigBounds);
        branchgroup.addChild(MouseCtrl3);
    }

	public void setObjectData(ArrayList<CadObject> cadObjects, Vector<Layer> layers)
	{
		this.cadObjects = cadObjects;
		this.layers = layers;
		
		ospRenderer = new OspRenderer(cadObjects, layers);
	}

	/**
	 * Setting the boundyries for the three views, the raster and the pixelresolution
	 */
	public void setBoundaries(Double boundaryWidth, Double boundaryHeight, Double boundaryDepth, Double rasterWidth, Double pixelPerMm)
	{
		this.boundaryWidth = boundaryWidth;
		this.boundaryHeight = boundaryHeight;
		this.boundaryDepth = boundaryDepth;
		this.rasterWidth = rasterWidth;
		this.pixelPerMm = pixelPerMm;
	}

	public void update3dView()
	{
		j3dObjectList.clear();
		j3dObjectList = ospRenderer.get3dObjectList();
		
//		System.out.println("objRoot.numChildren(): "+objRoot.numChildren());
		
        for(int j=objRoot.numChildren()-1; j>=0; j--) {	// startNumberOfChildren-1
        	if(objRoot.getChild(j) instanceof BranchGroup)
        		objRoot.removeChild(j);
        }

        // Adding the coordinate-Plane
        swapTG = getNewTransformGroup();
        swapTG.addChild(new CoordinatePlane().getPlane(new Vector3f(0.0f, 0.0f, 0.0f), 1.0f, 1));
        swapBG = getNewBranchGroup();
        swapBG.addChild(swapTG);

        // Adding the CadObjects
        for(int i=0; i<j3dObjectList.size(); i++) {
        	swapTG.addChild(j3dObjectList.get(i).getJ3dObject());
		}

        // ... and setting the mouseevents for the Canvas
        mouseEvent(swapBG, swapTG, bigBounds);
        
        // finaly add the complete branchgroup to the root
        objRoot.addChild(swapBG);
        
	}

	private void clear3dView()
	{
		System.out.println("clear3dView");
		
       for(int j=objRoot.numChildren()-1; j>=0; j--) {	// startNumberOfChildren-1
        	if(objRoot.getChild(j) instanceof BranchGroup)
        		objRoot.removeChild(j);
       }
	}

	private TransformGroup getNewTransformGroup()
	{
		TransformGroup tg = new TransformGroup();
		tg.setCapability(TransformGroup.ALLOW_TRANSFORM_READ);	// erlaubt lesenden und ...
		tg.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE); // schreibenden Zugriff auf die Transformgroup
		tg.setCapability(TransformGroup.ALLOW_CHILDREN_READ);
		tg.setCapability(TransformGroup.ALLOW_CHILDREN_WRITE);
		tg.setCapability(TransformGroup.ALLOW_CHILDREN_EXTEND);
	 	
		return tg;
	}
	
	private BranchGroup getNewBranchGroup()
	{
		BranchGroup bg = new BranchGroup();
		bg.setCapability(BranchGroup.ALLOW_CHILDREN_READ);
		bg.setCapability(BranchGroup.ALLOW_CHILDREN_WRITE);
		bg.setCapability(BranchGroup.ALLOW_CHILDREN_EXTEND);
		bg.setCapability(BranchGroup.ALLOW_DETACH);
	 	
		return bg;
	}
		
	// unused interface-methods
	public JPanel getPanel() {
		// TODO Auto-generated method stub
		return null;
	}
	// unused interface-methods - END

	public void actionPerformed(ActionEvent e)
	{
		System.out.println(e.getActionCommand());

		if(e.getActionCommand().equals("Update")) {
			update3dView();
		}
		else if(e.getActionCommand().equals("Clear")) {
			clear3dView();	
		}
	}

	public void mouseClicked(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mousePressed(MouseEvent e)
	{
		if(e.getButton()==MouseEvent.BUTTON2) {
			popup.show(e.getComponent(), e.getX(), e.getY());
		}
	}

	public void mouseReleased(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseEntered(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}

	public void mouseExited(MouseEvent e) {
		// TODO Auto-generated method stub
		
	}
}
