/*
Class-name: OspRenderer, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.preview3d;

import interfaces.CadObject;
import interfaces.J3dObject;
import interfaces.Layer;

import java.util.ArrayList;
import java.util.Vector;

import javax.media.j3d.Shape3D;
import javax.media.j3d.TransformGroup;

import com.sun.j3d.utils.geometry.Box;

public class OspRenderer
{
	public final int EXTRUDING_X = 0;	// Extruding in X-Direction
	public final int EXTRUDING_Y = 1;	// Extruding in Y-Direction
	public final int EXTRUDING_Z = 2;	// Extruding in Z-Direction (default)
	
	// Constants for 2D-objects
	public final int GEOMETRY_2D_LINE = 0;			// Geometrytyp is a simple line (default)
	public final int GEOMETRY_2D_POLYGON = 1;		// Geometrytyp is a poly-line
	public final int GEOMETRY_2D_RECTANGLE = 2;		// Geometrytyp is a rectangle
	public final int GEOMETRY_2D_CIRCLE = 3;		// Geometrytyp is a circle
	public final int GEOMETRY_2D_ELLIPSE = 4;		// Geometrytyp is a ellipse
	public final int GEOMETRY_2D_TRIANGLE = 5;		// Geometrytyp is a triangle
	public final int GEOMETRY_2D_SURFACE = 6;		// Geometrytyp is a surface
	
	// Constants for 3D-objects
	public static final int GEOMETRY_3D_SPHERE = 7;			// Geometrytyp is a sphere
	public static final int GEOMETRY_3D_CUBE = 8;			// Geometrytyp is a cube
	public static final int GEOMETRY_3D_BOX = 9;			// Geometrytyp is a box
	public static final int GEOMETRY_3D_CYLINDER = 10;		// Geometrytyp is a cylinder
	public static final int GEOMETRY_3D_CONE = 11;			// Geometrytyp is a cone	

	private ArrayList<CadObject> cadObjects;
	private Vector<Layer> layers;
	
	private ArrayList<J3dObject> j3dObjectList = new ArrayList<J3dObject>();

	private Double boundaryWidth = 800d, boundaryHeight = 800d, boundaryDepth = 800d, rasterWidth = 50d, pixelPerMm = 1d;

	public OspRenderer(ArrayList<CadObject> cadObjects, Vector<Layer> layers)
	{
		this.cadObjects = cadObjects;
		this.layers = layers;
	}
	
	/**
	 * Setting the boundyries for the three views, the raster and the pixelresolution
	 */
	public void setBoundaries(Double boundaryWidth, Double boundaryHeight, Double boundaryDepth, Double rasterWidth, Double pixelPerMm)
	{
		this.boundaryWidth = boundaryWidth;
		this.boundaryHeight = boundaryHeight;
		this.boundaryDepth = boundaryDepth;
		this.rasterWidth = rasterWidth;
		this.pixelPerMm = pixelPerMm;
	}

	/**
	 * 
	 * @return
	 */
	public ArrayList<J3dObject> get3dObjectList()
	{
		CadObject cadObject = null;
		Layer layer = null;
		int geometryTyp;
		J3dObject j3dObject = null;
		
		j3dObjectList.clear();
		
		for(int i=0; i<cadObjects.size(); i++) {
//			System.out.println("i: "+i);
			
			cadObject = cadObjects.get(i);
			layer = layers.get(cadObject.getLayerID());
			geometryTyp = cadObject.getGeometryTyp();
			
//			System.out.println("geometryTyp: "+geometryTyp);
			
			if(geometryTyp==GEOMETRY_2D_LINE)  {
				
			}
			else
				if(geometryTyp==GEOMETRY_2D_POLYGON)  {
					
			}else
				if(geometryTyp==GEOMETRY_2D_RECTANGLE)  {
					if(cadObject.isVisible() && cadObject.getTransparency()>0) {
						j3dObject = new J3dObjects.BoxObject(cadObject, layer);
						j3dObject.setBoundaries(boundaryWidth, boundaryHeight, boundaryDepth, rasterWidth, pixelPerMm);
						j3dObjectList.add(j3dObject);
						System.out.println("GEOMETRY_2D_RECTANGLE");	
					}
			}else
				if(geometryTyp==GEOMETRY_3D_CYLINDER)  {
					if(cadObject.isVisible()) {
						j3dObject = new J3dObjects.CircleObject(cadObject, layer);
						j3dObject.setBoundaries(boundaryWidth, boundaryHeight, boundaryDepth, rasterWidth, pixelPerMm);
						j3dObjectList.add(j3dObject);
					}
			}else
				if(geometryTyp==GEOMETRY_2D_ELLIPSE)  {
					
			} else
				if(geometryTyp==GEOMETRY_2D_TRIANGLE)  {
					
			} else
				if(geometryTyp==GEOMETRY_2D_SURFACE)  {
					
			}
			
		}
		
		return j3dObjectList;
	}
	
}
