/*
Class-name: RGBColorMap, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.preview3d;

import javax.vecmath.Color3f;

public class RGBColorMap
{
	public static final Color3f RED   	 = new Color3f(1.0f, 0.0f, 0.0f);
	public static final Color3f DARKRED  = new Color3f(1.0f, 0.5f, 0.5f);
	public static final Color3f BLUE  	 = new Color3f(0.0f, 0.0f, 1.0f);
    public static final Color3f GREEN 	 = new Color3f(0.0f, 1.0f, 0.0f);
    public static final Color3f WHITE 	 = new Color3f(1.0f, 1.0f, 1.0f);
    public static final Color3f BLACK 	 = new Color3f(0.0f, 0.0f, 0.0f);
    
    public static final Color3f[] map16 = new Color3f[16];
	{
		map16[0] = new Color3f(0.0f, 0.0f, 0.0f);
		map16[1] = new Color3f(0.0f, 0.0f, 0.3333f);
		map16[2] = new Color3f(0.0f, 0.0f, 0.6666f);
		map16[3] = new Color3f(0.0f, 0.0f, 1.0f);
		map16[4] = new Color3f(0.0f, 0.3333f, 1.0f);
		map16[5] = new Color3f(0.0f, 0.6666f, 1.0f);
		map16[6] = new Color3f(0.0f, 1.0f, 1.0f);
		map16[7] = new Color3f(0.0f, 1.0f, 0.6666f);
		map16[8] = new Color3f(0.0f, 1.0f, 0.333f);
		map16[9] = new Color3f(0.3333f, 1.0f, 0.0f);
		map16[10] = new Color3f(0.6666f, 1.0f, 0.0f);
		map16[11] = new Color3f(1.0f, 1.0f, 0.0f);
		map16[12] = new Color3f(1.0f, 0.6666f, 0.0f);
		map16[13] = new Color3f(1.0f, 0.3333f, 0.0f);
		map16[14] = new Color3f(1.0f, 0.0f, 0.0f);
		map16[15] = new Color3f(1.0f, 1.0f, 1.0f);
	}

	public static final Color3f[] map256 = new Color3f[256]; //private Color3f[] map256 = new Color3f[256];
	{
		for(int i=0; i<=255; i++) map256[i] = new Color3f(0.0f, 0.0f, 0.0f);

		map256[0].x = 0.0f; map256[0].y = 0.0f; map256[0].z = 1.0f;
		map256[1].x = 0.0f; map256[1].y = 0.015625f; map256[1].z = 1.0f;
		map256[2].x = 0.0f; map256[2].y = 0.03125f; map256[2].z = 1.0f;
		map256[3].x = 0.0f; map256[3].y = 0.046875f; map256[3].z = 1.0f;
		map256[4].x = 0.0f; map256[4].y = 0.0625f; map256[4].z = 1.0f;
		map256[5].x = 0.0f; map256[5].y = 0.078125f; map256[5].z = 1.0f;
		map256[6].x = 0.0f; map256[6].y = 0.09375f; map256[6].z = 1.0f;
		map256[7].x = 0.0f; map256[7].y = 0.109375f; map256[7].z = 1.0f;
		map256[8].x = 0.0f; map256[8].y = 0.125f; map256[8].z = 1.0f;
		map256[9].x = 0.0f; map256[9].y = 0.140625f; map256[9].z = 1.0f;
		map256[10].x = 0.0f; map256[10].y = 0.15625f; map256[10].z = 1.0f;
		map256[11].x = 0.0f; map256[11].y = 0.171875f; map256[11].z = 1.0f;
		map256[12].x = 0.0f; map256[12].y = 0.1875f; map256[12].z = 1.0f;
		map256[13].x = 0.0f; map256[13].y = 0.203125f; map256[13].z = 1.0f;
		map256[14].x = 0.0f; map256[14].y = 0.21875f; map256[14].z = 1.0f;
		map256[15].x = 0.0f; map256[15].y = 0.234375f; map256[15].z = 1.0f;
		map256[16].x = 0.0f; map256[16].y = 0.25f; map256[16].z = 1.0f;
		map256[17].x = 0.0f; map256[17].y = 0.265625f; map256[17].z = 1.0f;
		map256[18].x = 0.0f; map256[18].y = 0.28125f; map256[18].z = 1.0f;
		map256[19].x = 0.0f; map256[19].y = 0.296875f; map256[19].z = 1.0f;
		map256[20].x = 0.0f; map256[20].y = 0.3125f; map256[20].z = 1.0f;
		map256[21].x = 0.0f; map256[21].y = 0.328125f; map256[21].z = 1.0f;
		map256[22].x = 0.0f; map256[22].y = 0.34375f; map256[22].z = 1.0f;
		map256[23].x = 0.0f; map256[23].y = 0.359375f; map256[23].z = 1.0f;
		map256[24].x = 0.0f; map256[24].y = 0.375f; map256[24].z = 1.0f;
		map256[25].x = 0.0f; map256[25].y = 0.390625f; map256[25].z = 1.0f;
		map256[26].x = 0.0f; map256[26].y = 0.40625f; map256[26].z = 1.0f;
		map256[27].x = 0.0f; map256[27].y = 0.421875f; map256[27].z = 1.0f;
		map256[28].x = 0.0f; map256[28].y = 0.4375f; map256[28].z = 1.0f;
		map256[29].x = 0.0f; map256[29].y = 0.453125f; map256[29].z = 1.0f;
		map256[30].x = 0.0f; map256[30].y = 0.46875f; map256[30].z = 1.0f;
		map256[31].x = 0.0f; map256[31].y = 0.484375f; map256[31].z = 1.0f;
		map256[32].x = 0.0f; map256[32].y = 0.5f; map256[32].z = 1.0f;
		map256[33].x = 0.0f; map256[33].y = 0.515625f; map256[33].z = 1.0f;
		map256[34].x = 0.0f; map256[34].y = 0.53125f; map256[34].z = 1.0f;
		map256[35].x = 0.0f; map256[35].y = 0.546875f; map256[35].z = 1.0f;
		map256[36].x = 0.0f; map256[36].y = 0.5625f; map256[36].z = 1.0f;
		map256[37].x = 0.0f; map256[37].y = 0.578125f; map256[37].z = 1.0f;
		map256[38].x = 0.0f; map256[38].y = 0.59375f; map256[38].z = 1.0f;
		map256[39].x = 0.0f; map256[39].y = 0.609375f; map256[39].z = 1.0f;
		map256[40].x = 0.0f; map256[40].y = 0.625f; map256[40].z = 1.0f;
		map256[41].x = 0.0f; map256[41].y = 0.640625f; map256[41].z = 1.0f;
		map256[42].x = 0.0f; map256[42].y = 0.65625f; map256[42].z = 1.0f;
		map256[43].x = 0.0f; map256[43].y = 0.671875f; map256[43].z = 1.0f;
		map256[44].x = 0.0f; map256[44].y = 0.6875f; map256[44].z = 1.0f;
		map256[45].x = 0.0f; map256[45].y = 0.703125f; map256[45].z = 1.0f;
		map256[46].x = 0.0f; map256[46].y = 0.71875f; map256[46].z = 1.0f;
		map256[47].x = 0.0f; map256[47].y = 0.734375f; map256[47].z = 1.0f;
		map256[48].x = 0.0f; map256[48].y = 0.75f; map256[48].z = 1.0f;
		map256[49].x = 0.0f; map256[49].y = 0.765625f; map256[49].z = 1.0f;
		map256[50].x = 0.0f; map256[50].y = 0.78125f; map256[50].z = 1.0f;
		map256[51].x = 0.0f; map256[51].y = 0.796875f; map256[51].z = 1.0f;
		map256[52].x = 0.0f; map256[52].y = 0.8125f; map256[52].z = 1.0f;
		map256[53].x = 0.0f; map256[53].y = 0.828125f; map256[53].z = 1.0f;
		map256[54].x = 0.0f; map256[54].y = 0.84375f; map256[54].z = 1.0f;
		map256[55].x = 0.0f; map256[55].y = 0.859375f; map256[55].z = 1.0f;
		map256[56].x = 0.0f; map256[56].y = 0.875f; map256[56].z = 1.0f;
		map256[57].x = 0.0f; map256[57].y = 0.890625f; map256[57].z = 1.0f;
		map256[58].x = 0.0f; map256[58].y = 0.90625f; map256[58].z = 1.0f;
		map256[59].x = 0.0f; map256[59].y = 0.921875f; map256[59].z = 1.0f;
		map256[60].x = 0.0f; map256[60].y = 0.9375f; map256[60].z = 1.0f;
		map256[61].x = 0.0f; map256[61].y = 0.953125f; map256[61].z = 1.0f;
		map256[62].x = 0.0f; map256[62].y = 0.96875f; map256[62].z = 1.0f;
		map256[63].x = 0.0f; map256[63].y = 0.984375f; map256[63].z = 1.0f;
		map256[64].x = 0.0f; map256[64].y = 1.0f; map256[64].z = 1.0f;
		map256[65].x = 0.0f; map256[65].y = 1.0f; map256[65].z = 0.984375f;
		map256[66].x = 0.0f; map256[66].y = 1.0f; map256[66].z = 0.96875f;
		map256[67].x = 0.0f; map256[67].y = 1.0f; map256[67].z = 0.953125f;
		map256[68].x = 0.0f; map256[68].y = 1.0f; map256[68].z = 0.9375f;
		map256[69].x = 0.0f; map256[69].y = 1.0f; map256[69].z = 0.921875f;
		map256[70].x = 0.0f; map256[70].y = 1.0f; map256[70].z = 0.90625f;
		map256[71].x = 0.0f; map256[71].y = 1.0f; map256[71].z = 0.890625f;
		map256[72].x = 0.0f; map256[72].y = 1.0f; map256[72].z = 0.875f;
		map256[73].x = 0.0f; map256[73].y = 1.0f; map256[73].z = 0.859375f;
		map256[74].x = 0.0f; map256[74].y = 1.0f; map256[74].z = 0.84375f;
		map256[75].x = 0.0f; map256[75].y = 1.0f; map256[75].z = 0.828125f;
		map256[76].x = 0.0f; map256[76].y = 1.0f; map256[76].z = 0.8125f;
		map256[77].x = 0.0f; map256[77].y = 1.0f; map256[77].z = 0.796875f;
		map256[78].x = 0.0f; map256[78].y = 1.0f; map256[78].z = 0.78125f;
		map256[79].x = 0.0f; map256[79].y = 1.0f; map256[79].z = 0.765625f;
		map256[80].x = 0.0f; map256[80].y = 1.0f; map256[80].z = 0.75f;
		map256[81].x = 0.0f; map256[81].y = 1.0f; map256[81].z = 0.734375f;
		map256[82].x = 0.0f; map256[82].y = 1.0f; map256[82].z = 0.71875f;
		map256[83].x = 0.0f; map256[83].y = 1.0f; map256[83].z = 0.703125f;
		map256[84].x = 0.0f; map256[84].y = 1.0f; map256[84].z = 0.6875f;
		map256[85].x = 0.0f; map256[85].y = 1.0f; map256[85].z = 0.671875f;
		map256[86].x = 0.0f; map256[86].y = 1.0f; map256[86].z = 0.65625f;
		map256[87].x = 0.0f; map256[87].y = 1.0f; map256[87].z = 0.640625f;
		map256[88].x = 0.0f; map256[88].y = 1.0f; map256[88].z = 0.625f;
		map256[89].x = 0.0f; map256[89].y = 1.0f; map256[89].z = 0.609375f;
		map256[90].x = 0.0f; map256[90].y = 1.0f; map256[90].z = 0.59375f;
		map256[91].x = 0.0f; map256[91].y = 1.0f; map256[91].z = 0.578125f;
		map256[92].x = 0.0f; map256[92].y = 1.0f; map256[92].z = 0.5625f;
		map256[93].x = 0.0f; map256[93].y = 1.0f; map256[93].z = 0.546875f;
		map256[94].x = 0.0f; map256[94].y = 1.0f; map256[94].z = 0.53125f;
		map256[95].x = 0.0f; map256[95].y = 1.0f; map256[95].z = 0.515625f;
		map256[96].x = 0.0f; map256[96].y = 1.0f; map256[96].z = 0.5f;
		map256[97].x = 0.0f; map256[97].y = 1.0f; map256[97].z = 0.484375f;
		map256[98].x = 0.0f; map256[98].y = 1.0f; map256[98].z = 0.46875f;
		map256[99].x = 0.0f; map256[99].y = 1.0f; map256[99].z = 0.453125f;
		map256[100].x = 0.0f; map256[100].y = 1.0f; map256[100].z = 0.4375f;
		map256[101].x = 0.0f; map256[101].y = 1.0f; map256[101].z = 0.421875f;
		map256[102].x = 0.0f; map256[102].y = 1.0f; map256[102].z = 0.40625f;
		map256[103].x = 0.0f; map256[103].y = 1.0f; map256[103].z = 0.390625f;
		map256[104].x = 0.0f; map256[104].y = 1.0f; map256[104].z = 0.375f;
		map256[105].x = 0.0f; map256[105].y = 1.0f; map256[105].z = 0.359375f;
		map256[106].x = 0.0f; map256[106].y = 1.0f; map256[106].z = 0.34375f;
		map256[107].x = 0.0f; map256[107].y = 1.0f; map256[107].z = 0.328125f;
		map256[108].x = 0.0f; map256[108].y = 1.0f; map256[108].z = 0.3125f;
		map256[109].x = 0.0f; map256[109].y = 1.0f; map256[109].z = 0.296875f;
		map256[110].x = 0.0f; map256[110].y = 1.0f; map256[110].z = 0.28125f;
		map256[111].x = 0.0f; map256[111].y = 1.0f; map256[111].z = 0.265625f;
		map256[112].x = 0.0f; map256[112].y = 1.0f; map256[112].z = 0.25f;
		map256[113].x = 0.0f; map256[113].y = 1.0f; map256[113].z = 0.234375f;
		map256[114].x = 0.0f; map256[114].y = 1.0f; map256[114].z = 0.21875f;
		map256[115].x = 0.0f; map256[115].y = 1.0f; map256[115].z = 0.203125f;
		map256[116].x = 0.0f; map256[116].y = 1.0f; map256[116].z = 0.1875f;
		map256[117].x = 0.0f; map256[117].y = 1.0f; map256[117].z = 0.171875f;
		map256[118].x = 0.0f; map256[118].y = 1.0f; map256[118].z = 0.15625f;
		map256[119].x = 0.0f; map256[119].y = 1.0f; map256[119].z = 0.140625f;
		map256[120].x = 0.0f; map256[120].y = 1.0f; map256[120].z = 0.125f;
		map256[121].x = 0.0f; map256[121].y = 1.0f; map256[121].z = 0.109375f;
		map256[122].x = 0.0f; map256[122].y = 1.0f; map256[122].z = 0.09375f;
		map256[123].x = 0.0f; map256[123].y = 1.0f; map256[123].z = 0.078125f;
		map256[124].x = 0.0f; map256[124].y = 1.0f; map256[124].z = 0.0625f;
		map256[125].x = 0.0f; map256[125].y = 1.0f; map256[125].z = 0.046875f;
		map256[126].x = 0.0f; map256[126].y = 1.0f; map256[126].z = 0.03125f;
		map256[127].x = 0.0f; map256[127].y = 1.0f; map256[127].z = 0.015625f;
		map256[128].x = 0.0f; map256[128].y = 1.0f; map256[128].z = 0.0f;
		map256[129].x = 0.015625f; map256[129].y = 1.0f; map256[129].z = 0.0f;
		map256[130].x = 0.03125f; map256[130].y = 1.0f; map256[130].z = 0.0f;
		map256[131].x = 0.046875f; map256[131].y = 1.0f; map256[131].z = 0.0f;
		map256[132].x = 0.0625f; map256[132].y = 1.0f; map256[132].z = 0.0f;
		map256[133].x = 0.078125f; map256[133].y = 1.0f; map256[133].z = 0.0f;
		map256[134].x = 0.09375f; map256[134].y = 1.0f; map256[134].z = 0.0f;
		map256[135].x = 0.109375f; map256[135].y = 1.0f; map256[135].z = 0.0f;
		map256[136].x = 0.125f; map256[136].y = 1.0f; map256[136].z = 0.0f;
		map256[137].x = 0.140625f; map256[137].y = 1.0f; map256[137].z = 0.0f;
		map256[138].x = 0.15625f; map256[138].y = 1.0f; map256[138].z = 0.0f;
		map256[139].x = 0.171875f; map256[139].y = 1.0f; map256[139].z = 0.0f;
		map256[140].x = 0.1875f; map256[140].y = 1.0f; map256[140].z = 0.0f;
		map256[141].x = 0.203125f; map256[141].y = 1.0f; map256[141].z = 0.0f;
		map256[142].x = 0.21875f; map256[142].y = 1.0f; map256[142].z = 0.0f;
		map256[143].x = 0.234375f; map256[143].y = 1.0f; map256[143].z = 0.0f;
		map256[144].x = 0.25f; map256[144].y = 1.0f; map256[144].z = 0.0f;
		map256[145].x = 0.265625f; map256[145].y = 1.0f; map256[145].z = 0.0f;
		map256[146].x = 0.28125f; map256[146].y = 1.0f; map256[146].z = 0.0f;
		map256[147].x = 0.296875f; map256[147].y = 1.0f; map256[147].z = 0.0f;
		map256[148].x = 0.3125f; map256[148].y = 1.0f; map256[148].z = 0.0f;
		map256[149].x = 0.328125f; map256[149].y = 1.0f; map256[149].z = 0.0f;
		map256[150].x = 0.34375f; map256[150].y = 1.0f; map256[150].z = 0.0f;
		map256[151].x = 0.359375f; map256[151].y = 1.0f; map256[151].z = 0.0f;
		map256[152].x = 0.375f; map256[152].y = 1.0f; map256[152].z = 0.0f;
		map256[153].x = 0.390625f; map256[153].y = 1.0f; map256[153].z = 0.0f;
		map256[154].x = 0.40625f; map256[154].y = 1.0f; map256[154].z = 0.0f;
		map256[155].x = 0.421875f; map256[155].y = 1.0f; map256[155].z = 0.0f;
		map256[156].x = 0.4375f; map256[156].y = 1.0f; map256[156].z = 0.0f;
		map256[157].x = 0.453125f; map256[157].y = 1.0f; map256[157].z = 0.0f;
		map256[158].x = 0.46875f; map256[158].y = 1.0f; map256[158].z = 0.0f;
		map256[159].x = 0.484375f; map256[159].y = 1.0f; map256[159].z = 0.0f;
		map256[160].x = 0.5f; map256[160].y = 1.0f; map256[160].z = 0.0f;
		map256[161].x = 0.515625f; map256[161].y = 1.0f; map256[161].z = 0.0f;
		map256[162].x = 0.53125f; map256[162].y = 1.0f; map256[162].z = 0.0f;
		map256[163].x = 0.546875f; map256[163].y = 1.0f; map256[163].z = 0.0f;
		map256[164].x = 0.5625f; map256[164].y = 1.0f; map256[164].z = 0.0f;
		map256[165].x = 0.578125f; map256[165].y = 1.0f; map256[165].z = 0.0f;
		map256[166].x = 0.59375f; map256[166].y = 1.0f; map256[166].z = 0.0f;
		map256[167].x = 0.609375f; map256[167].y = 1.0f; map256[167].z = 0.0f;
		map256[168].x = 0.625f; map256[168].y = 1.0f; map256[168].z = 0.0f;
		map256[169].x = 0.640625f; map256[169].y = 1.0f; map256[169].z = 0.0f;
		map256[170].x = 0.65625f; map256[170].y = 1.0f; map256[170].z = 0.0f;
		map256[171].x = 0.671875f; map256[171].y = 1.0f; map256[171].z = 0.0f;
		map256[172].x = 0.6875f; map256[172].y = 1.0f; map256[172].z = 0.0f;
		map256[173].x = 0.703125f; map256[173].y = 1.0f; map256[173].z = 0.0f;
		map256[174].x = 0.71875f; map256[174].y = 1.0f; map256[174].z = 0.0f;
		map256[175].x = 0.734375f; map256[175].y = 1.0f; map256[175].z = 0.0f;
		map256[176].x = 0.75f; map256[176].y = 1.0f; map256[176].z = 0.0f;
		map256[177].x = 0.765625f; map256[177].y = 1.0f; map256[177].z = 0.0f;
		map256[178].x = 0.78125f; map256[178].y = 1.0f; map256[178].z = 0.0f;
		map256[179].x = 0.796875f; map256[179].y = 1.0f; map256[179].z = 0.0f;
		map256[180].x = 0.8125f; map256[180].y = 1.0f; map256[180].z = 0.0f;
		map256[181].x = 0.828125f; map256[181].y = 1.0f; map256[181].z = 0.0f;
		map256[182].x = 0.84375f; map256[182].y = 1.0f; map256[182].z = 0.0f;
		map256[183].x = 0.859375f; map256[183].y = 1.0f; map256[183].z = 0.0f;
		map256[184].x = 0.875f; map256[184].y = 1.0f; map256[184].z = 0.0f;
		map256[185].x = 0.890625f; map256[185].y = 1.0f; map256[185].z = 0.0f;
		map256[186].x = 0.90625f; map256[186].y = 1.0f; map256[186].z = 0.0f;
		map256[187].x = 0.921875f; map256[187].y = 1.0f; map256[187].z = 0.0f;
		map256[188].x = 0.9375f; map256[188].y = 1.0f; map256[188].z = 0.0f;
		map256[189].x = 0.953125f; map256[189].y = 1.0f; map256[189].z = 0.0f;
		map256[190].x = 0.96875f; map256[190].y = 1.0f; map256[190].z = 0.0f;
		map256[191].x = 0.984375f; map256[191].y = 1.0f; map256[191].z = 0.0f;
		map256[192].x = 1.0f; map256[192].y = 1.0f; map256[192].z = 0.0f;
		map256[193].x = 1.0f; map256[193].y = 0.984375f; map256[193].z = 0.0f;
		map256[194].x = 1.0f; map256[194].y = 0.96875f; map256[194].z = 0.0f;
		map256[195].x = 1.0f; map256[195].y = 0.953125f; map256[195].z = 0.0f;
		map256[196].x = 1.0f; map256[196].y = 0.9375f; map256[196].z = 0.0f;
		map256[197].x = 1.0f; map256[197].y = 0.921875f; map256[197].z = 0.0f;
		map256[198].x = 1.0f; map256[198].y = 0.90625f; map256[198].z = 0.0f;
		map256[199].x = 1.0f; map256[199].y = 0.890625f; map256[199].z = 0.0f;
		map256[200].x = 1.0f; map256[200].y = 0.875f; map256[200].z = 0.0f;
		map256[201].x = 1.0f; map256[201].y = 0.859375f; map256[201].z = 0.0f;
		map256[202].x = 1.0f; map256[202].y = 0.84375f; map256[202].z = 0.0f;
		map256[203].x = 1.0f; map256[203].y = 0.828125f; map256[203].z = 0.0f;
		map256[204].x = 1.0f; map256[204].y = 0.8125f; map256[204].z = 0.0f;
		map256[205].x = 1.0f; map256[205].y = 0.796875f; map256[205].z = 0.0f;
		map256[206].x = 1.0f; map256[206].y = 0.78125f; map256[206].z = 0.0f;
		map256[207].x = 1.0f; map256[207].y = 0.765625f; map256[207].z = 0.0f;
		map256[208].x = 1.0f; map256[208].y = 0.75f; map256[208].z = 0.0f;
		map256[209].x = 1.0f; map256[209].y = 0.734375f; map256[209].z = 0.0f;
		map256[210].x = 1.0f; map256[210].y = 0.71875f; map256[210].z = 0.0f;
		map256[211].x = 1.0f; map256[211].y = 0.703125f; map256[211].z = 0.0f;
		map256[212].x = 1.0f; map256[212].y = 0.6875f; map256[212].z = 0.0f;
		map256[213].x = 1.0f; map256[213].y = 0.671875f; map256[213].z = 0.0f;
		map256[214].x = 1.0f; map256[214].y = 0.65625f; map256[214].z = 0.0f;
		map256[215].x = 1.0f; map256[215].y = 0.640625f; map256[215].z = 0.0f;
		map256[216].x = 1.0f; map256[216].y = 0.625f; map256[216].z = 0.0f;
		map256[217].x = 1.0f; map256[217].y = 0.609375f; map256[217].z = 0.0f;
		map256[218].x = 1.0f; map256[218].y = 0.59375f; map256[218].z = 0.0f;
		map256[219].x = 1.0f; map256[219].y = 0.578125f; map256[219].z = 0.0f;
		map256[220].x = 1.0f; map256[220].y = 0.5625f; map256[220].z = 0.0f;
		map256[221].x = 1.0f; map256[221].y = 0.546875f; map256[221].z = 0.0f;
		map256[222].x = 1.0f; map256[222].y = 0.53125f; map256[222].z = 0.0f;
		map256[223].x = 1.0f; map256[223].y = 0.515625f; map256[223].z = 0.0f;
		map256[224].x = 1.0f; map256[224].y = 0.5f; map256[224].z = 0.0f;
		map256[225].x = 1.0f; map256[225].y = 0.484375f; map256[225].z = 0.0f;
		map256[226].x = 1.0f; map256[226].y = 0.46875f; map256[226].z = 0.0f;
		map256[227].x = 1.0f; map256[227].y = 0.453125f; map256[227].z = 0.0f;
		map256[228].x = 1.0f; map256[228].y = 0.4375f; map256[228].z = 0.0f;
		map256[229].x = 1.0f; map256[229].y = 0.421875f; map256[229].z = 0.0f;
		map256[230].x = 1.0f; map256[230].y = 0.40625f; map256[230].z = 0.0f;
		map256[231].x = 1.0f; map256[231].y = 0.390625f; map256[231].z = 0.0f;
		map256[232].x = 1.0f; map256[232].y = 0.375f; map256[232].z = 0.0f;
		map256[233].x = 1.0f; map256[233].y = 0.359375f; map256[233].z = 0.0f;
		map256[234].x = 1.0f; map256[234].y = 0.34375f; map256[234].z = 0.0f;
		map256[235].x = 1.0f; map256[235].y = 0.328125f; map256[235].z = 0.0f;
		map256[236].x = 1.0f; map256[236].y = 0.3125f; map256[236].z = 0.0f;
		map256[237].x = 1.0f; map256[237].y = 0.296875f; map256[237].z = 0.0f;
		map256[238].x = 1.0f; map256[238].y = 0.28125f; map256[238].z = 0.0f;
		map256[239].x = 1.0f; map256[239].y = 0.265625f; map256[239].z = 0.0f;
		map256[240].x = 1.0f; map256[240].y = 0.25f; map256[240].z = 0.0f;
		map256[241].x = 1.0f; map256[241].y = 0.234375f; map256[241].z = 0.0f;
		map256[242].x = 1.0f; map256[242].y = 0.21875f; map256[242].z = 0.0f;
		map256[243].x = 1.0f; map256[243].y = 0.203125f; map256[243].z = 0.0f;
		map256[244].x = 1.0f; map256[244].y = 0.1875f; map256[244].z = 0.0f;
		map256[245].x = 1.0f; map256[245].y = 0.171875f; map256[245].z = 0.0f;
		map256[246].x = 1.0f; map256[246].y = 0.15625f; map256[246].z = 0.0f;
		map256[247].x = 1.0f; map256[247].y = 0.140625f; map256[247].z = 0.0f;
		map256[248].x = 1.0f; map256[248].y = 0.125f; map256[248].z = 0.0f;
		map256[249].x = 1.0f; map256[249].y = 0.109375f; map256[249].z = 0.0f;
		map256[250].x = 1.0f; map256[250].y = 0.09375f; map256[250].z = 0.0f;
		map256[251].x = 1.0f; map256[251].y = 0.078125f; map256[251].z = 0.0f;
		map256[252].x = 1.0f; map256[252].y = 0.0625f; map256[252].z = 0.0f;
		map256[253].x = 1.0f; map256[253].y = 0.046875f; map256[253].z = 0.0f;
		map256[254].x = 1.0f; map256[254].y = 0.03125f; map256[254].z = 0.0f;
		map256[255].x = 1.0f; map256[255].y = 0.015625f; map256[255].z = 0.0f;
		
//		for(int i=0; i<=63; i++) {	// blau bis cyan
//		map256[i].x = 0.0f;
//		map256[i].y = (((float)i/(float)64));
//		map256[i].z = 1.0f;
//	}
//	for(int i=64; i<=127; i++) { // cyan bis gr�n
//		map256[i].x = 0.0f;
//		map256[i].y = 1.0f; 
//		map256[i].z = ((float)1.0f - (((float)i-(float)64)/(float)64));
//	}
//	for(int i=128; i<=191; i++) {	// gr�n bis gelb
//		map256[i].x = ((((float)i-(float)128)/(float)64));
//		map256[i].y = 1.0f;
//		map256[i].z = 0.0f;
//	}
//	for(int i=192; i<=255; i++) {	// gelb bis rot
//		map256[i].x = 1.0f;
//		map256[i].y = ((float)1.0f - (((float)i-(float)192)/(float)64));
//		map256[i].z = 0.0f;
//	}
		
		//		for(int i=0; i<=41; i++) {	// schwarz bis blau
//			map256[i].x = 0.0f;
//			map256[i].y = 0.0f;
//			map256[i].z = (((float)i/(float)42));
//		}
//		for(int i=42; i<=84; i++) {	// blau bis cyan
//			map256[i].x = 0.0f;
//			map256[i].y = ((((float)i-(float)42)/(float)42));
//			map256[i].z = 1.0f;
//		}
//		for(int i=85; i<=127; i++) { // cyan bis gr�n
//			map256[i].x = 0.0f;
//			map256[i].y = 1.0f; 
//			map256[i].z = ((float)1.0f - (((float)i-(float)85)/(float)42));
//		}
//		for(int i=128; i<=170; i++) {	// gr�n bis gelb
//			map256[i].x = ((((float)i-(float)128)/(float)42));
//			map256[i].y = 1.0f;
//			map256[i].z = 0.0f;
//		}
//		for(int i=171; i<=255; i++) {	// gelb bis rot
//			map256[i].x = 1.0f;
//			map256[i].y = ((float)1.0f - (((float)i-(float)171)/(float)84));
//			map256[i].z = 0.0f;
//		}

		}

	public RGBColorMap()
	{
//		System.out.println("map256.length: "+map256.length);
//		for(int i=0; i<=map256.length-1;i++)
//			System.out.println("map256["+i+"].x = "+map256[i].x+"f; map256["+i+"].y = "+map256[i].y+"f; map256["+i+"].z = "+map256[i].z+"f;");
	}
	
	public Color3f[] getMap16()
	{
		return map16;
	}

	public static Color3f[] getMap256()
	{
		return map256;
	}
}
