/*
Class-name: GeometricsBar.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.toolBars;

import interfaces.CadObject;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JToolBar;
import javax.swing.border.EmptyBorder;

import modeller.ModellerStack;
import modeller.tools.ImportObjects;
import modeller.tools.ImportUrlClass;
import modeller.tools.IniParser;

public class GeometricsBar extends JToolBar implements ActionListener
{
	private ModellerStack modellerStack;
	
	private JButton swapButton;
	private Thread rotatingColor;
	
	public GeometricsBar(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		this.setToolTipText("Geometrics-Toolbar");
		this.setName("Geometrics-Toolbar");
		
		new IniParser(modellerStack);
		
//		rotatingColor = new Thread(new RotatingColor());
//		rotatingColor.start();
		
		ImportObjects importObject;
		ButtonGroup buttonGroup = new ButtonGroup();
		
		String[] splitOfImageIconNames = modellerStack.imageIconNames.split(",");
		for(int i=0; i<splitOfImageIconNames.length; i++) {
			importObject = modellerStack.importUrlClass.getImportObjects().get(splitOfImageIconNames[i]);
			swapButton = initGemetricsButton(importObject.getImageIcon(), importObject.getName(), importObject.getToolTipText());
			swapButton.setEnabled(importObject.isEnabled());
			swapButton.setVisible(importObject.isVisible());
			buttonGroup.add(swapButton);
			this.add(swapButton);
		}
	}
	
	/**
	 * Initializing the ToggleButtons for the improted FemObjects
	 * @param imageIcon
	 * @param name
	 * @param toolTopText
	 * @return
	 */
	private JButton initGemetricsButton(String imageIcon, String name, String toolTopText)
	{
		JButton swapButton = new JButton(new ImageIcon(imageIcon)); swapButton.setName(name);
		swapButton.setBorderPainted(false); swapButton.setBackground(this.getBackground());
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText(toolTopText);
		swapButton.addActionListener(this);
		
		return swapButton;
	}
	
	/**
	 * Initializing a new FemObject and setting the LayerID
	 * @param obj
	 * @return
	 */
	private void initNewFemObject(CadObject obj)
	{
		modellerStack.selectionToolButtonPressed = false;
		modellerStack.stillBuilding = true;
		modellerStack.objectMoving = false;
		modellerStack.currentCadObject = obj;
		modellerStack.currentCadObject.setLayerID(modellerStack.layerPanel[0].getLayer().getLayerID());
		modellerStack.currentObjectPanelID = modellerStack.currentDrawPanelID;
		modellerStack.drawPanels[modellerStack.currentDrawPanelID].setFetchButtonReleased(false);
	}
	
	public void actionPerformed(ActionEvent e)
	{
		JButton button = (JButton)e.getSource();
		String name = button.getName();
		String path;
		
		System.out.println(name);
		
		if(modellerStack.swapButton==null)
			modellerStack.swapButton = new JButton();
		
		if(modellerStack.swapButton!=button) {
			button.setBorderPainted(true);	button.setBackground(Color.WHITE); modellerStack.swapButton.setBackground(this.getBackground());
			
			if(rotatingColor==null) {
				rotatingColor = new Thread(new RotatingColor());
				rotatingColor.start();
			}

		}
		modellerStack.swapButton = button;
		
		modellerStack.hotSpots.clear();
		
		modellerStack.selectedObject = -1;
		
		modellerStack.repaintDrawPanels();
		
		try {
			path = modellerStack.importUrlClass.getImportObjects().get(name).getPath();
			initNewFemObject(modellerStack.importUrlClass.importClass(name, path, ImportUrlClass.IMPORT_CAD));
			}
		catch (Exception e1) { e1.printStackTrace(); }
		
		// Updating the fem-object-properties with the propertie-values of the selected layer
		modellerStack.objectsProperties.updateObjectList(modellerStack.currentCadObject, true);
	}
	
	class RotatingColor implements Runnable
	{
		public void run()
		{						// 'run' wird bei Thread-Aufruf thread.start(); automatisch ausgefuehrt
			int i = 0;

			while(true) {
				while((i+=30)<255) {					// Durchlaufen der Schleife bis Zaehler 255 erreicht hat
					modellerStack.swapButton.setBackground(new Color(i, i, i));	// Zuweisen der Hintergrundfarbe der TextArea
					
					try {
						Thread.sleep(100);			// Thread fuer 5ms einrieren
					} catch (InterruptedException e) {
						e.printStackTrace();
					}	
				}
				i = 0;
				while((i+=30)<255) {					// Durchlaufen der Schleife bis Zaehler 255 erreicht hat
					modellerStack.swapButton.setBackground(new Color(255-i, 255-i, 255-i));	// Zuweisen der Hintergrundfarbe der TextArea
					
					try {
						Thread.sleep(100);			// Thread fuer 5ms einrieren
					} catch (InterruptedException e) {
						e.printStackTrace();
					}	
				}
			}
		}
	}
	
}
