/*
Class-name: ToolsBar.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.toolBars;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JToolBar;
import javax.swing.border.EmptyBorder;

import modeller.ModellerStack;

public class ToolsBar extends JToolBar implements ActionListener
{
	private ModellerStack modellerStack;	// Controller-Class for managing the mouse-interaction

	private JButton swapButton;

	public ToolsBar(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		
		this.setToolTipText("Tools-bar");
		this.setName("Tools-bar");
		
		swapButton = new JButton(new ImageIcon("images/snapOnClick.png")); swapButton.setName("snapFree");
		swapButton.setBorderPainted(false);	swapButton.setBackground(this.getBackground());
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Snap free");
		swapButton.addActionListener(this);
		this.add(swapButton);
		
		swapButton = new JButton(new ImageIcon("images/move_object.png")); swapButton.setName("moveObject");
		swapButton.setBorderPainted(false);	swapButton.setBackground(this.getBackground());
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Move object");
		swapButton.addActionListener(this);
		this.add(swapButton);
		
//		swapButton = new JButton(new ImageIcon("images/stretch_object.png")); swapButton.setName("stretchObject");
//		swapButton.setVisible(false); swapButton.setEnabled(false);
//		swapButton.setBorderPainted(false);	swapButton.setBackground(this.getBackground());
//		swapButton.setBorder(new EmptyBorder(1,1,1,1));
//		swapButton.setToolTipText("stretch object");
//		swapButton.addActionListener(this);
//		this.add(swapButton);
		
		swapButton = new JButton(new ImageIcon("images/snapByWindow.png")); swapButton.setName("snapWindow");
		swapButton.setBorderPainted(false);	swapButton.setBackground(this.getBackground());
		swapButton.setEnabled(false);
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Snap by window");
		swapButton.addActionListener(this);
		this.add(swapButton);
		
		swapButton = null;

	}
	
	public void actionPerformed(ActionEvent e)
	{
		JButton button = (JButton)e.getSource();
		
		modellerStack.stillBuilding = false;
		modellerStack.objectMoving = false;
		modellerStack.objectStretching = false;
		
		
		modellerStack.selectionToolButtonPressed = false;
		
		if(modellerStack.swapButton==null)
			modellerStack.swapButton = new JButton();
		
		if(modellerStack.swapButton!=button) {
			button.setBorderPainted(true);	button.setBackground(Color.WHITE); modellerStack.swapButton.setBackground(this.getBackground());
		}
		modellerStack.swapButton = button;
		
		if(button.getName().equals("snapFree")) {
			modellerStack.selectionToolButtonPressed = true;
		}
		else if(button.getName().equals("moveObject")) {
			System.out.println("selectedObject: "+modellerStack.selectedObject);
			modellerStack.objectMoving = true;
		}
		else if(button.getName().equals("stretchObject")) {
			System.out.println("selectedObject: "+modellerStack.selectedObject);
			modellerStack.objectStretching = true;
		}

		System.out.println(button.getName());
	}

}
