/*
Class-name: ViewBar.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/
package modeller.toolBars;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JMenuItem;
import javax.swing.JToolBar;
import javax.swing.border.EmptyBorder;

import modeller.DrawPanel;
import modeller.ModellerStack;
import modeller.draw.StaticDrawing;

public class ViewBar extends JToolBar implements ActionListener, ItemListener
{
	private ModellerStack modellerStack;
	private DrawPanel drawPanel;
	private JComboBox zoomBox;
	private JButton swapButton;
//	private JLabel scalingFactor;
	private double[] zoomFactor = {0.05, 0.1, 0.25, 0.33, 0.5, 0.75, 1.0, 1.5, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 10.0};
	
	public ViewBar(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;

		modellerStack.viewBar = this;
		
		
		zoomBox = new JComboBox(new String[]{"5 %", "10 %", "25 %", "33 %", "50 %", "75 %", "100 %", "150 %", "200 %", "300 %", "400 %", "500 %", "600 %", "700 %", "800 %", "1000 %"});
		zoomBox.addItemListener(this);
		zoomBox.setSelectedIndex(6);
		zoomBox.setEditable(true);
		zoomBox.setPreferredSize(new Dimension(80, 22));
		zoomBox.setMaximumSize(new Dimension(80, 22));
		
		this.setToolTipText("View-Toolbar");
		this.setName("View-Toolbar");
		
		swapButton = new JButton(new ImageIcon("images/lupe_plus.png")); swapButton.setName("zoomIn");
		swapButton.setBorderPainted(false);
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Zoom-In");
		swapButton.addActionListener(this);
		this.add(swapButton);
		swapButton = new JButton(new ImageIcon("images/lupe_minus.png"));  swapButton.setName("zoomOut");
		swapButton.setBorderPainted(false);
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Zoom-Out");
		swapButton.addActionListener(this);
		this.add(swapButton);
		swapButton = new JButton(new ImageIcon("images/lupe_window.png"));  swapButton.setName("viewPan");
		swapButton.setBorderPainted(false);	swapButton.setEnabled(false);
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("Zoom by window");
		swapButton.addActionListener(this);
		this.add(swapButton);
		swapButton = new JButton(new ImageIcon("images/lupe_100.png"));  swapButton.setName("100Percent");
		swapButton.setBorderPainted(false);
		swapButton.setBorder(new EmptyBorder(1,1,1,1));
		swapButton.setToolTipText("100 %");
		swapButton.addActionListener(this);
		this.add(swapButton);
		this.addSeparator(new Dimension(2,22));
		
		this.add(zoomBox);
		
	}

	public void aEvents(ActionEvent e, boolean mode)
	{
		String name = "";
		double scale;
		
		if((e.getSource() instanceof JButton) || (e.getSource() instanceof JMenuItem)) {
			if((e.getSource() instanceof JButton))
				name = ((JButton)e.getSource()).getName();
			else if((e.getSource() instanceof JMenuItem))
				name = ((JMenuItem)e.getSource()).getName();
			
			drawPanel = (modellerStack.drawPanels[modellerStack.currentDrawPanelID]);
			if(name.equals("zoomIn")) {		
				if(mode) {
					for(int i=0; i<3; i++) {
						modellerStack.drawPanels[i].setScale(modellerStack.drawPanels[i].getScale()*1.1f);
	//						if(!modellerStack.drawMode) break;
					}
					scale = modellerStack.drawPanels[modellerStack.currentDrawPanelID].getScale();
				}
				else {
					drawPanel.setScale(drawPanel.getScale()*1.1f);
//					drawPanel.setScale(zoomBox.getSelectedIndex());
					scale = drawPanel.getScale();
				}
//				StaticDrawing.setAllCadObjectsRendered(modellerStack.cadObjects, false);
			}
			else if(name.equals("zoomOut")) {
				if(mode) {
					for(int i=0; i<3; i++) {
						modellerStack.drawPanels[i].setScale(modellerStack.drawPanels[i].getScale()/1.1f);
	//						if(!modellerStack.drawMode) break;
					}
					scale = modellerStack.drawPanels[modellerStack.currentDrawPanelID].getScale();
				}
				else {
					drawPanel.setScale(drawPanel.getScale()/1.1f);
					scale = drawPanel.getScale();
				}
//				StaticDrawing.setAllCadObjectsRendered(modellerStack.cadObjects, false);

			}
			else if(name.equals("100Percent")) {
				for(int i=0; i<3; i++) {
					modellerStack.drawPanels[i].setScale(1f);
//					if(!modellerStack.drawMode) break;
				}
				zoomBox.setSelectedIndex(6);
//				StaticDrawing.setAllCadObjectsRendered(modellerStack.cadObjects, false);
			}
			else if(name.equals("fullscreen")) {
				System.out.println("Fullscreen on desktop "+modellerStack.currentDrawPanelID);
				((JMenuItem)e.getSource()).setName("redoFullscreen");
				((JMenuItem)e.getSource()).setText("Back to 3D-View");
				modellerStack.modellerPanel.updateDrawPanelContainer(modellerStack.currentDrawPanelID, false);
			}
			else if(name.equals("redoFullscreen")) {
				System.out.println("Redo fullscreen on desktop "+modellerStack.currentDrawPanelID);
				((JMenuItem)e.getSource()).setName("fullscreen");
				((JMenuItem)e.getSource()).setText("Fullscreen");
				modellerStack.modellerPanel.updateDrawPanelContainer(modellerStack.currentDrawPanelID, true);
			}
			modellerStack.repaintDrawPanels();
//			StaticDrawing.setAllCadObjectsRendered(modellerStack.cadObjects, true);
		}
	}
	
	public void actionPerformed(ActionEvent e)
	{
//		System.out.println("ViewBar: actionPerformed");
		aEvents(e, true);
	}

	public void itemStateChanged(ItemEvent e)
	{
		if(e.getSource() instanceof JComboBox) {
			if(e.getStateChange()==ItemEvent.SELECTED) {
				int index = ((JComboBox)(e.getSource())).getSelectedIndex();
				System.out.println("index: "+index);
				
				// Resizing all drawPanels
				for(int i=0; i<3; i++) {
					drawPanel = (modellerStack.drawPanels[i]);
					if(drawPanel!=null) {
						drawPanel.setScale(zoomFactor[index]);
						drawPanel.refreshDimension();
					}
				}
			}
		}
	}

}
