/*
Class-name: ImportUrlClass.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.tools;

import interfaces.CadObject;
import interfaces.ExportImportObject;

import java.io.File;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.HashMap;

import modeller.ModellerStack;

public class ImportUrlClass
{
	public static final int IMPORT_CAD = 0;
	public static final int EXPORTFILTER = 1;
	public static final int IMPORTFILTER = 2;
	public static final int IMPORT_SIMULATOR = 3;
	
	private HashMap<String, ImportObjects> importObjects = new HashMap<String, ImportObjects>();
	private ModellerStack modellerStack;

	public ImportUrlClass(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
	}
	
	/**
	 * <u>getFemObject - getting an instance of FemObject by name</u><br>
	 * @param file
	 */
	public CadObject importClass(String name, String path, int importTyp) throws Exception  
	{
		CadObject cadObject;
		
	    URLClassLoader cl = new URLClassLoader(new URL[] { new File(path).toURL() });
		Class c = cl.loadClass(name);

	    if(importTyp==IMPORT_CAD) {	// Importing a CAD-object for painting
		    return (CadObject)c.newInstance();
		}
	    else if(importTyp==EXPORTFILTER) {	// Starting the CAD-export
	    	ExportImportObject exportImportObject = (ExportImportObject)c.newInstance();
	    	exportImportObject.exportObjects(modellerStack.cadObjects, modellerStack.layers, modellerStack.currentCadPath);
	    	if(exportImportObject.getCurrentFilePath()!=null)
	    		modellerStack.currentCadPath = exportImportObject.getCurrentFilePath();
	    	
			return null;
		}
	    else if(importTyp==IMPORTFILTER) {	// Starting the CAD-import
	    	System.out.println("Try to importObjects");
	    	ExportImportObject exportImportObject = (ExportImportObject)c.newInstance();
	    	exportImportObject.importObjects(modellerStack.cadObjects, modellerStack.layers, new File(modellerStack.currentCadPath), name, path);
	    	if(exportImportObject.getCurrentFilePath()!=null)
	    		modellerStack.currentCadPath = exportImportObject.getCurrentFilePath();
	    	
	    	// Resetting all neccessary flags
	    	for(int i=0; i<modellerStack.cadObjects.size(); i++) {
	    		cadObject = modellerStack.cadObjects.get(i);
	    		cadObject.setRendered2D(false);
	    		cadObject.setInBuildProcess(false);
	    	}
	    	
	    	// updating the layer-view, after importing the layers
	    	modellerStack.objectsPanel.updateObjectTree();
//	    	modellerStack.layerPanel[0].updateLayer();
	    	modellerStack.layerPanel[0].updateLayer(0); modellerStack.layerPanel[1].updateLayer(0);
	    	modellerStack.repaintDrawPanels();
	    	
			return null;
		}
	    else if(importTyp==IMPORT_SIMULATOR) {
	    	
	    	return null;
	    }
		else return null;
	}
	
	public ExportImportObject getExportObject(String name, String path, int importTyp) throws Exception  
	{
	    URLClassLoader cl = new URLClassLoader(new URL[] { new File(path).toURL() });
		Class c = cl.loadClass(name);
		ExportImportObject exportImportObject = (ExportImportObject)c.newInstance();
//		
		return exportImportObject;
	}
	
	
	public void putNewImportObject(String name, String toolTipText, String path, String image, String typ, String suffix, Boolean visible, Boolean enabled, Boolean showInFrame)
	{
		importObjects.put(name, new ImportObjects(name, toolTipText, path, image, typ, suffix, visible, enabled, showInFrame));
	}
	
	public HashMap<String, ImportObjects> getImportObjects() {
		return importObjects;
	}
}