/*
Class-name: IniParser.java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.tools;

//import gui.Objects;

import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;

import modeller.ModellerStack;

import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

/**
 * Class: IniParse, parsing-class for plugin-inifile)
 * @author Karsten Bettray <br>
 * &copy Karsten Bettray - 2006<br>
 */
public class IniParser
{
	private static boolean printStr = false;
	private ModellerStack modellerStack;
	
	public IniParser(ModellerStack modellerStack)
	{
		this.modellerStack = modellerStack;
		
		objectProperties("initObject.xml");
	}
	
	/**
	 * <u>Auslesen der Ini-Datei-Werte im ausgew&auml;hlten Projekt</u><br>
	 * @return R&uuml;ckgabe einer HashMap
	 */
	private void objectProperties(String fileName)
	{
		DocumentBuilder db = null;
		org.w3c.dom.Document document = null; 	// Das XML-Dokument
		XPath xPath;							// XPath-Objekt, zum einlesen der Elemente und Attribute
		NodeList nodes = null;					// Knotenlisten		
		
		try {
			db = DocumentBuilderFactory.newInstance().newDocumentBuilder();
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
		}
		
		try { document = db.parse(fileName); }
		catch (SAXException e) { e.printStackTrace(); }
		catch (IOException e) { e.printStackTrace();
		}

		xPath = XPathFactory.newInstance().newXPath();
			
		// parsing the XML-import
		try {
			String name, toolTipText, path, imageIcon, typ, suffix;
			Boolean visible, enabled, showInFrame;
			nodes = (NodeList)xPath.evaluate("/initObjects/object", document, XPathConstants.NODESET);
			for(int i=0; i<=nodes.getLength()-1; i++) {
				name = (String)(xPath.evaluate("./@name", nodes.item(i)));
				toolTipText = (String)(xPath.evaluate("./@toolTipText", nodes.item(i)));
				path = (String)(xPath.evaluate("./@path", nodes.item(i)));
				imageIcon = (String)(xPath.evaluate("./@image", nodes.item(i)));
				typ = (String)(xPath.evaluate("./@typ", nodes.item(i)));
				suffix = (String)(xPath.evaluate("./@suffix", nodes.item(i)));
				visible = new Boolean((String)(xPath.evaluate("./@visible", nodes.item(i))));
				enabled = new Boolean((String)(xPath.evaluate("./@enabled", nodes.item(i))));
				showInFrame = new Boolean((String)(xPath.evaluate("./@showInFrame", nodes.item(i))));
				
				// namelist for hashmap of graphic-classes, exportfilter-classes an d simulator-classes
				if(typ.equals("graphicalObject"))
					modellerStack.imageIconNames += name +",";
				else if(typ.equals("exportFormat"))
					modellerStack.exportFormatNames += name +",";
				else if(typ.equals("importFormat"))
					modellerStack.importFormatNames += name +",";
				else if(typ.equals("simulator"))
					modellerStack.simulatorClassesNames += name +",";
				
				modellerStack.importUrlClass.putNewImportObject(name, toolTipText, path, imageIcon, typ, suffix, visible, enabled, showInFrame);
				
				if(printStr)
					System.out.println(modellerStack.importUrlClass.getImportObjects().get(name).toString());
			}
			
			// deleting the last ','
			modellerStack.imageIconNames = modellerStack.imageIconNames.substring(0, modellerStack.imageIconNames.length()-1);
			modellerStack.exportFormatNames = modellerStack.exportFormatNames.substring(0, modellerStack.exportFormatNames.length()-1);
			modellerStack.importFormatNames = modellerStack.importFormatNames.substring(0, modellerStack.importFormatNames.length()-1);
			modellerStack.simulatorClassesNames = modellerStack.simulatorClassesNames.substring(0, modellerStack.simulatorClassesNames.length()-1);			
		}
		catch (XPathExpressionException e) { e.printStackTrace(); }
	}
}
