/*
Class-name: StaticMethods-java, part of the 'Open-Simulation-Platform'

The 'Open-Simulation-Platform' provides a dynamically GUI, with a plugable 2D/3D CAD-interface and a (soon) integrated plugable simulation-interface 

Copyright (C) 2006 Karsten Bettray

This program is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library;
if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA *
*/

package modeller.tools;

import java.util.ArrayList;
import java.util.Vector;

import modeller.ModellerStack;

import interfaces.CadObject;
import interfaces.Layer;
import interfaces.Vertex;

public class StaticMethods
{
	public static void updateLayerdata(ArrayList<CadObject> cadObjects, Vector<Layer> layers)
	{
		Layer layer = null;
		CadObject cadObject = null;
		
		for(int i=0; i < cadObjects.size(); i++) {
			cadObject = cadObjects.get(i);
			layer = layers.get(cadObject.getLayerID());
			
			cadObject.setLineColor(layer.getLineColor());
			cadObject.setFillColor(layer.getFillColor());
			cadObject.setLineWidth(layer.getLineWidth());
			cadObject.setLineTyp(layer.getLineTyp());
			cadObject.setTransparency(layer.getTransparency());
			cadObject.setExtrudingDirection(layer.getExtrudingDirection());
			cadObject.setExtrusionStart(layer.getExtrusionStart());
			cadObject.setExtrusionStop(layer.getExtrusionStop());
		}
	}
	
	public static void resetPaintBit(ArrayList<CadObject> cadObjects, int layerID)
	{
//		CadObject cadObject = null;
		
		for(int i=0; i < cadObjects.size(); i++)
			if(cadObjects.get(i).getLayerID()==layerID)
				cadObjects.get(i).setRendered2D(false);
	}

	public static void autoSizeCADObjects(ModellerStack modellerStack)
	{
		double xMin = 0, yMin = 0, zMin = 0, xMax = 0, yMax = 0, zMax = 0, dx = 0, dy = 0, dz = 0;
		int cadObjectSize = modellerStack.cadObjects.size();
		int vertexListSize;
		CadObject cadObject;
		Vertex vertex;
		
		cadObject = modellerStack.cadObjects.get(0);
		vertex = cadObject.getVertexList().get(0);
		
		// Initializing min/max
		xMin = vertex.getX();
		yMin = vertex.getY();
		zMin = vertex.getZ();
		xMax = vertex.getX();
		yMax = vertex.getY();
		zMax = vertex.getZ();

		for(int i=0; i<cadObjectSize; i++) {
			cadObject = modellerStack.cadObjects.get(i);
			vertexListSize = cadObject.getVertexList().size();

			// searching minima & maxima
			for(int j=1; j<vertexListSize; j++) {
				vertex = cadObject.getVertexList().get(j);
				if(vertex.getX()<=xMin) xMin = vertex.getX();
				else if(vertex.getX()>xMax) xMax = vertex.getX();
				
				if(vertex.getY()<=yMin) yMin = vertex.getY();
				else if(vertex.getY()>yMax) yMax = vertex.getY();
				
				if(vertex.getZ()<=zMin) zMin = vertex.getZ();
				else if(vertex.getZ()>zMax) zMax = vertex.getZ();
				
//				System.out.println("("+(i+1)+"/"+cadObjectSize+") Comparing "+(j+1)+" of "+vertexListSize);
				
			}
		}
		
		// matching the ranges of the dimensions
		dx = xMax - xMin;
		dy = yMax - yMin;
		dz = zMax - zMin;
		
		System.out.println("xMin: "+xMin+", yMin: "+yMin+", zMin: "+zMin);
		System.out.println("xMax: "+xMax+", yMax: "+yMax+", zMax: "+zMax);
		System.out.println("dx: "+dx+", dy: "+dy+", dz: "+dz);
		System.out.println("dx/modellerStack.boundaryWidth: "+(dx/modellerStack.boundaryWidth)+"" +
						   ", dy/modellerStack.boundaryHeight: "+(dy/modellerStack.boundaryHeight)+"" +
						   ", dz/modellerStack.boundaryDepth: "+(dz/modellerStack.boundaryDepth));
		
		// updating the 'Millimeter per pixel' value
		if(dx>modellerStack.boundaryWidth || dy>modellerStack.boundaryHeight || dz>modellerStack.boundaryDepth) {
			modellerStack.pixelPerMm = 1d / (Math.abs(Math.max(dz, Math.max(dx, dy))) / Math.abs(Math.min(modellerStack.boundaryDepth, Math.min(modellerStack.boundaryWidth, modellerStack.boundaryHeight))));
//			modellerStack.pixelPerMm = 1d / Math.abs(Math.min(dz/modellerStack.boundaryDepth, Math.min(dx/modellerStack.boundaryWidth, dy/modellerStack.boundaryHeight)));
//			pixelPerMm.setText(""+modellerStack.pixelPerMm);
		}
		
		// setting up the translation, if nessesary
		if(xMin<0)
			addTranslationToObjectPoints(modellerStack, 0, -xMin);
		
		if(yMin<0)
			addTranslationToObjectPoints(modellerStack, 1, -yMin);

		if(zMin<0)
			addTranslationToObjectPoints(modellerStack, 2, -zMin);
		
		modellerStack.repaintDrawPanels();
	}

	public static void addTranslationToObjectPoints(ModellerStack modellerStack, int direction, double minValue)
	{
		int cadObjectSize = modellerStack.cadObjects.size();
		int vertexListSize;
		CadObject cadObject;
		Vertex vertex;

		for(int i=0; i<cadObjectSize; i++) {
			cadObject = modellerStack.cadObjects.get(i);
			vertexListSize = cadObject.getVertexList().size();
			
			for(int j=0; j<vertexListSize; j++) {
				vertex = cadObject.getVertexList().get(j);
				
				if(direction==0)
					vertex.setX(vertex.getX()+minValue);
				else if(direction==1)
					vertex.setY(vertex.getY()+minValue);
				else
					vertex.setZ(vertex.getZ()+minValue);
			}
		}

	}

	
}
